*decomp_mcohab.do
capture log close
log using "U:\papers and projects\earnings associations\do\sensitivity_rr\decomp_mcohab.log", replace
set more 1
clear
program drop _all
set mem 500M

set matsize 3000



#delimit cr




   use "U:\papers and projects\earnings associations\dta\earn_tab_20_ties_mcohab.dta", clear


   *Year categories

    #delimit ;
    recode y  1968/1971 = 1968 1972/1975 = 1972 1976/1979 = 1976 1980/1983 = 1980
              1984/1987 = 1984 1988/1991 = 1988 1992/1995 = 1992 1996/1999 = 1996
              2000/2003 = 2000 2004/2006 = 2004 ;
    #delimit cr


    collapse (sum) freq WEIGHT (mean) Wscale Hscale, by(y Hp Wp)


      summarize Wscale [w=freq]
      summarize Hscale [w=freq]


    **LOGGED AN NON-LOGGED INCOME VARIABLES


      gen oWscale = Wscale
      gen oHscale = Hscale

      replace Wscale = ln(Wscale) if Wscale ~= 0
      replace Hscale = ln(Hscale) if Hscale ~= 0





    **UA STANDARDIZED NON-LOGGED INCOME


      expand freq


      foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
        quietly egen zoWscale`num' = std(oWscale) if /*oWscale ~= 0 &*/  y == `num'
        quietly egen zoHscale`num' = std(oHscale) if /*oHscale ~= 0 &*/  y == `num'
      }


      gen zoWscale = 0
      gen zoHscale = 0


      foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
       quietly replace zoWscale = zoWscale`num' if y == `num'
       quietly replace zoHscale = zoHscale`num' if y == `num'
      }


      gen ua_std_exp = zoWscale*zoHscale

      drop zo*



    **UA STANDARDIZED LOGGED INCOME




      foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
        quietly egen zWscale`num' = std(Wscale) if Wscale ~= 0 &  y == `num'
        quietly egen zHscale`num' = std(Hscale) if Hscale ~= 0 &  y == `num'
      }

      gen zWscale = 0
      gen zHscale = 0

      foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
       quietly replace zWscale = zWscale`num' if y == `num' & Wscale ~= 0
       quietly replace zHscale = zHscale`num' if y == `num' & Hscale ~= 0
      }


      gen ua_std_ln = zWscale*zHscale



     collapse (mean) freq WEIGHT oWscale oHscale Wscale Hscale ua_std_ln ua_std_exp, by(y Hp Wp)


      *Make sure this collapse worked
      summarize oWscale [w=freq]
      summarize oHscale [w=freq]

***Distance, excluding zeros


   gen d = 0
   replace d = abs(Wp - Hp) if Wp ~= 0 & Hp ~= 0


**Absolute value of logged difference

 gen sd_hw = abs(Wscale-Hscale)
 replace sd_hw = 0 if Wp == 0 | Hp == 0


  #delimit ;

   ******************
   * WEIGHTING CODE *
   ****************** ;


   ***To weight the data, follow Agresti page 391 section 9.7.5.

      zi = the total weighted frequency divided by the cell
      count.  In my case, this is:

      WEIGHT/freq = zi

      Loglinear models for the weighted expected frequencies
      (zi*mui = mui/ti) with ti = 1/zi expresses the model as
      a standard loglinear model for logmui with offset
      (logti = -logzi).

      What this means is the offset is equal to:

      -ln(zi)

      crs 2/25/04 ;


   #delimit cr


   gen zi      = (WEIGHT/freq)
   gen neglnzi = -ln(zi)


  *Deal with zero cells
   replace neglnzi = 0 if neglnzi == .



   **********************
   * GENERATE VARIABLES *
   **********************




   ***Special parameters for those married to partners with no earnings
      gen hz = (Hp == 0 & Wp > 0 )
      gen wz = (Wp == 0 & Hp > 0 )

      quietly gen hzC = 0
      quietly gen wzC = 0

      quietly foreach num of numlist 5(5)100 {
       quietly replace hzC = `num' if (hz == 1 & Wp == `num')
       quietly replace wzC = `num' if (wz == 1 & Hp  == `num')
      }


    gen z = 0
    replace z = 1 if Wp == 0 & Hp == 0
    replace z = 2  if Wp == 0 & Hp == 10
    replace z = 3  if Wp == 0 & Hp == 20
    replace z = 4  if Wp == 0 & Hp == 30
    replace z = 5  if Wp == 0 & Hp == 40
    replace z = 6  if Wp == 0 & Hp == 50
    replace z = 7  if Wp == 0 & Hp == 60
    replace z = 8  if Wp == 0 & Hp == 70
    replace z = 9  if Wp == 0 & Hp == 80
    replace z = 10 if Wp == 0 & Hp == 90
    replace z = 11 if Wp == 0 & Hp == 100
    replace z = 12 if Hp == 0 & Wp == 10
    replace z = 13 if Hp == 0 & Wp == 20
    replace z = 14 if Hp == 0 & Wp == 30
    replace z = 15 if Hp == 0 & Wp == 40
    replace z = 16 if Hp == 0 & Wp == 50
    replace z = 17 if Hp == 0 & Wp == 60
    replace z = 18 if Hp == 0 & Wp == 70
    replace z = 19 if Hp == 0 & Wp == 80
    replace z = 20 if Hp == 0 & Wp == 90
    replace z = 21 if Hp == 0 & Wp == 100




    ***Distance, excluding zeros


      foreach num of numlist 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
       gen y`num' = (y == `num')
       quietly gen wzHpy`num' = (wz*Hp*y`num')
       quietly gen wzHp2y`num' = (wz*Hp*Hp*y`num')
       quietly gen hzWpy`num' = (hz*Wp*y`num')
      }

      foreach num of numlist 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
       quietly gen uazy`num' = (ua_std_ln*y`num')
       quietly gen uay`num'  = (ua_std_exp*y`num')
       quietly gen wzy`num'   = (wz*y`num')
       quietly gen hzy`num'   = (hz*y`num')
      }

      foreach num of numlist 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
        quietly gen dy`num' = (d*y`num')
        quietly gen sd_hwy`num' = (sd_hw*y`num')
      }


      gen wzHp  = wz*Hp
      gen wzHp2 = wz*Hp*Hp
      gen hzWp  = hz*Wp

      gen fwag = oWscale + oHscale



        list fwag oWscale oHscale WEIGHT if y == 1968
        list fwag oWscale oHscale WEIGHT if y == 2000



      forvalues i = 20(10)100 {
       gen Hp`i' = (Hp == `i')
       gen Hp`i'ws = (Hp`i'*Wscale)
      }


      foreach num of numlist 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
       forvalues i = 20(10)100 {
        quietly gen wsHp`i'y`num' = (Wscale*Hp`i'*y`num')
       }
      }



   ***************************
   * END: GENERATE VARIABLES *
   ***************************






**************************************************************
*                                                            *
* STEP 1.  (a) Run different models of the assocation        *
*              between husbands' and wives' earnings.        *
*                                                            *
*          (b) Determine the implications of these models    *
*              for the predicted correlation between         *
*              spouses.                                      *
*                                                            *
*          (c) Determine the implications of these models    *
*              for earnings inequality across married        *
*              couples.                                      *
*                                                            *
*          The models are:                                   *
*                                                            *
*          (1) Fixed distance + earnings difference model.   *
*          (2) No association model among dual earners.      *
*          (3) No association among earners and zero earners *
*          (4) No association at all.                        *
*                                                            *
**************************************************************






***********************************************************
* FIRST MODEL: FIXED DISTANCE + REAL EARNINGS DIFFERENCE  *
***********************************************************




       ***::::FD + SD model with hw::::***

          gen f03 = freq

          #delimit ;
          xi: glm f03 i.Wp*i.y i.Hp*i.y i.Wp*i.Hp    /*WpY HpY WpHp*/
                      dy????   sd_hwy????       /*dY and earnings difference*/
                      wzHpy???? wzHp2y????           /*zeros*/
                      wzy????
                                   , family(poisson) link(log) offset(neglnzi) ;
          #delimit cr


          matrix b=e(b)
          svmat b, n(eqcol)

          predict fhat, nooffset


   *******************************************
   ***DESCRIPTIVES USING PREDICTED VALUES  ***
   *******************************************



      foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
       quietly corr oWscale oHscale [aw=fhat] if y == `num'
       quietly gen r`num' = r(rho)
      }


      preserve


      keep r????
      collapse r????

      gen id = _n
      reshape long r, i(id) j(y)


      ********************
      ***Predicted Corr***
      ********************


          #delimit ;
          twoway connected r y, yscale(r(-.1 .25)) c(l) clstyle(p2 p2 p2 p2 p2 p2) ylabel(-.1(.05).25)
                                          mcolor(blue red brown purple lime gs4)
                                          clcolor(blue red brown purple lime gs4)
                                          xlabel(#15)
                                          title("Predicted Corr Between Spouses' Earnings") sub("FD")
                                          ytitle("Predicted Corr") xtitle("year") ;
          #delimit cr


          list y r if y == 1968 | y == 2004


      ***Save these variables for later use***

          rename r rFDSD
          sort y

          tempfile corrFDSD
          save `corrFDSD'


      restore



      ******************************
      *** 80/50 and 80/20 ratios ***
      ******************************


             gen T = oWscale+oHscale

             preserve

               #delimit ;


               collapse (p10)  p10T=T
                        (p20)  p20T=T
                        (p40)  p40T=T
                        (p45)  p45T=T
                        (p50)  p50T=T
                        (p55)  p55T=T
                        (p60)  p60T=T
                        (p80)  p80T=T
                        [w=fhat] , by(y) ;

               #delimit cr


       **SAVE data set with the values of the percentiles for total earnings


         sort y
         keep y p*
         tempfile tps
         save `tps'

      restore

      **Merge on total percentages


     preserve

      sort y
      merge y using `tps'
      drop _merge

      replace fhat = round(fhat,1)


      keep T p* y fhat

      expand fhat

      **Sum of everyone's earnings by year
        bysort y: egen totalT = sum(T)

      **Earnings of top 20%
        bysort y: egen t_80 = sum(T) if T >= p80T

      **Earnings of bottom 20%
        bysort y: egen t_20 = sum(T) if T <= p20T

      **Earnings of middle 20%
        bysort y: egen t_4060 = sum(T) if T >  p20T & T <  p80T


      collapse t_80 t_20 t_4060 totalT, by(y)

      foreach num of numlist 80 20 4060 {
       gen p`num' = t_`num'/totalT
      }


      gen k8020 = p80/p20
      gen k8050 = p80/p4060
      gen k5020 = p4060/p20

      sort y
      tempfile kuz
      save `kuz'


           list k5020 k8050 k8020 if y == 1968 | y == 2004



           ***Save these variables for later use***

               foreach x in k5020 k8050 k8020 {
                 rename `x' `x'FDSD
               }

               sort y

               tempfile ratioFDSD
               save `ratioFDSD'



           restore








      ******************************
      *** CHANGE IN CV           ***
      ******************************



           preserve

            foreach var of varlist oHscale oWscale fwag {
              foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {

                quietly summarize `var' [aw=fhat] if y == `num'
                scalar def  V`var'`num'  = (r(sd))
                scalar def  M`var'`num' = (r(mean))
                scalar def CV`var'`num' = V`var'`num'/M`var'`num'

            }
            }

            display CVfwag1968
            display CVfwag2004

       #delimit ;


          *OBSERVED CHANGE IN CV ;

          foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {  ;

          scalar def a = MoHscale`num'/Mfwag`num' ;
          scalar def b = MoWscale`num'/Mfwag`num' ;

          scalar def const_CV2`num' = (a^2*CVoHscale`num'^2) +
                                    (b^2*CVoWscale`num'^2) +
                                    (2*r`num'*a*b*CVoHscale`num'*CVoWscale`num') ;

          gen CVf`num' = sqrt(const_CV2`num') ;


          } ;


          #delimit cr


          forvalues j = 1968(4)2004 {
            gen pchh`j' = (CVoHscale`j'-CVoHscale1968)/CVoHscale1968
            gen pchw`j' = (CVoWscale`j'-CVoWscale1968)/CVoWscale1968
            gen pchf`j' = (CVfwag`j'-CVfwag1968)/CVfwag1968
          }

         keep in 1
         keep pch* CVf*
         gen id = 1
         reshape long pchh pchw pchf CVf  , i(id) j(y)


         lab var pchh "CV, husbands"
         lab var pchw "CV, wives"
         lab var pchf "CV, couples"

         ***Predicted Percentage Change in CVs***

         #delimit ;
         twoway connected pchh pchw pchf y, /*yscale(r(1.4 2.0)) c(l) clstyle(p2 p2 p2 p2 p2 p2) ylabel(1.4(.2)2.0)*/
                                         mcolor(blue red brown purple lime gs4)
                                         clcolor(blue red brown purple lime gs4)
                                         xlabel(#15)
                                         title("Percent Change in CV by Source") sub("FD")
                                         ytitle("% Change (Base Year = 1968)") xtitle("year") ;
         #delimit cr




      ***Save these variables for later use***

          rename CVf cvFDSD
          sort y

          tempfile cvFDSD
          save `cvFDSD'


         restore




      drop fhat r???? f03*







**************************************************************
*                                                            *
* STEP 2.  (a) Now run a model without changes in the assoc  *
*              between husbands' and wives' earnings.        *
*                                                            *
*          (b) Determine the implications of this model      *
*              for the predicted correlation between         *
*              spouses.                                      *
*                                                            *
*          (c) Determine the implications of this model      *
*              for earnings inequality across married        *
*              couples.                                      *
*                                                            *
*          This model is:                                    *
*                                                            *
*          (1) Model 1 + preferred zeros specification       *
*                                                            *
**************************************************************



*************************************
* MODEL 1 + PREFERRED ZEROS SPEC    *
*************************************



          gen f03 = freq

          #delimit ;
          xi: glm f03 i.Wp*i.y i.Hp*i.y i.Wp*i.Hp    /*WpY HpY WpHp*/
                      wzHpy???? wzHp2y????           /*zeros*/
                      wzy????
                                   , family(poisson) link(log) offset(neglnzi) ;
          #delimit cr


          matrix b=e(b)
          svmat b, n(eqcol)

          predict fhat, nooffset





   ****************************************************************
   ***DESCRIPTIVES USING PREDICTED VALUES --- preferred zeros   ***
   ****************************************************************



      foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
       quietly corr oWscale oHscale [aw=fhat] if y == `num'
       quietly gen r`num' = r(rho)
      }


      preserve


      keep r????
      collapse r????

      gen id = _n
      reshape long r, i(id) j(y)


      ********************
      ***Predicted Corr***
      ********************


          #delimit ;
          twoway connected r y, yscale(r(-.1 .25)) c(l) clstyle(p2 p2 p2 p2 p2 p2) ylabel(-.1(.05).25)
                                          mcolor(blue red brown purple lime gs4)
                                          clcolor(blue red brown purple lime gs4)
                                          xlabel(#15)
                                          title("Predicted Corr Between Spouses' Earnings") sub("ZB")
                                          ytitle("Predicted Corr") xtitle("year") ;
          #delimit cr


          list y r if y == 1968 | y == 2004


      ***Save these variables for later use***

          rename r rZB
          sort y

          tempfile corrZB
          save `corrZB'


      restore



      ******************************
      *** 80/50 and 80/20 ratios ***
      ******************************



             preserve

               #delimit ;


               collapse (p10)  p10T=T
                        (p20)  p20T=T
                        (p40)  p40T=T
                        (p45)  p45T=T
                        (p50)  p50T=T
                        (p55)  p55T=T
                        (p60)  p60T=T
                        (p80)  p80T=T
                        [w=fhat] , by(y) ;

               #delimit cr


       **SAVE data set with the values of the percentiles for total earnings


         sort y
         keep y p*
         tempfile tps
         save `tps'

      restore

      **Merge on total percentages


     preserve

      sort y
      merge y using `tps'
      drop _merge

      replace fhat = round(fhat,1)


      keep T p* y fhat

      expand fhat

      **Sum of everyone's earnings by year
        bysort y: egen totalT = sum(T)

      **Earnings of top 20%
        bysort y: egen t_80 = sum(T) if T >= p80T

      **Earnings of bottom 20%
        bysort y: egen t_20 = sum(T) if T <= p20T

      **Earnings of middle 20%
        bysort y: egen t_4060 = sum(T) if T >  p20T & T <  p80T


      collapse t_80 t_20 t_4060 totalT, by(y)

      foreach num of numlist 80 20 4060 {
       gen p`num' = t_`num'/totalT
      }


      gen k8020 = p80/p20
      gen k8050 = p80/p4060
      gen k5020 = p4060/p20

      sort y
      tempfile kuz
      save `kuz'


           list k5020 k8050 k8020 if y == 1968 | y == 2004



           ***Save these variables for later use***

               foreach x in k5020 k8050 k8020 {
                 rename `x' `x'ZB
               }

               sort y

               tempfile ratioZB
               save `ratioZB'



           restore






      ******************************
      *** CHANGE IN CV           ***
      ******************************


           preserve

            foreach var of varlist oHscale oWscale fwag {
              foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {

                quietly summarize `var' [aw=fhat] if y == `num'
                scalar def  V`var'`num'  = (r(sd))
                scalar def  M`var'`num' = (r(mean))
                scalar def CV`var'`num' = V`var'`num'/M`var'`num'

            }
            }

            display CVfwag1968
            display CVfwag2004

       #delimit ;


          *OBSERVED CHANGE IN CV ;

          foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {  ;

          scalar def a = MoHscale`num'/Mfwag`num' ;
          scalar def b = MoWscale`num'/Mfwag`num' ;

          scalar def const_CV2`num' = (a^2*CVoHscale`num'^2) +
                                    (b^2*CVoWscale`num'^2) +
                                    (2*r`num'*a*b*CVoHscale`num'*CVoWscale`num') ;

          gen CVf`num' = sqrt(const_CV2`num') ;


          } ;


          #delimit cr


          forvalues j = 1968(4)2004 {
            gen pchh`j' = (CVoHscale`j'-CVoHscale1968)/CVoHscale1968
            gen pchw`j' = (CVoWscale`j'-CVoWscale1968)/CVoWscale1968
            gen pchf`j' = (CVfwag`j'-CVfwag1968)/CVfwag1968
          }

         keep in 1
         keep pch* CVf*
         gen id = 1
         reshape long pchh pchw pchf CVf  , i(id) j(y)


         lab var pchh "CV, husbands"
         lab var pchw "CV, wives"
         lab var pchf "CV, couples"

         ***Predicted Percentage Change in CVs***

         #delimit ;
         twoway connected pchh pchw pchf y, /*yscale(r(1.4 2.0)) c(l) clstyle(p2 p2 p2 p2 p2 p2) ylabel(1.4(.2)2.0)*/
                                         mcolor(blue red brown purple lime gs4)
                                         clcolor(blue red brown purple lime gs4)
                                         xlabel(#15)
                                         title("Percent Change in CV by Source") sub("Predicted ZB")
                                         ytitle("% Change (Base Year = 1968)") xtitle("year") ;
         #delimit cr





      ***Save these variables for later use***

          rename CVf cvZB
          sort y

          tempfile cvZB
          save `cvZB'

         restore




      drop fhat r???? f03*






**************************************************************
*                                                            *
* STEP 3.  Now run a model without any of the zeros          *
*          blocked. This is the baseline model.              *
*                                                            *
**************************************************************



*************
* MODEL 1   *
*************



          gen f03 = freq

          #delimit ;
          xi: glm f03 i.Wp*i.y i.Hp*i.y i.Wp*i.Hp    /*WpY HpY WpHp*/
                                   , family(poisson) link(log) offset(neglnzi) ;
          #delimit cr


          matrix b=e(b)
          svmat b, n(eqcol)

          predict fhat, nooffset





   **********************************************************************
   ***DESCRIPTIVES USING PREDICTED VALUES --- MODEL 1                 ***
   **********************************************************************



      foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
       quietly corr oWscale oHscale [aw=fhat] if y == `num'
       quietly gen r`num' = r(rho)
      }


      preserve


      keep r????
      collapse r????

      gen id = _n
      reshape long r, i(id) j(y)


      ********************
      ***Predicted Corr***
      ********************


          #delimit ;
          twoway connected r y, yscale(r(-.1 .25)) c(l) clstyle(p2 p2 p2 p2 p2 p2) ylabel(-.1(.05).25)
                                          mcolor(blue red brown purple lime gs4)
                                          clcolor(blue red brown purple lime gs4)
                                          xlabel(#15)
                                          title("Predicted Corr Between Spouses' Earnings") sub("NZ")
                                          ytitle("Predicted Corr") xtitle("year") ;
          #delimit cr


          list y r if y == 1968 | y == 2004


      ***Save these variables for later use***

          rename r rNZ
          sort y

          tempfile corrNZ
          save `corrNZ'


      restore



      ******************************
      *** 80/50 and 80/20 ratios ***
      ******************************



             preserve

               #delimit ;


               collapse (p10)  p10T=T
                        (p20)  p20T=T
                        (p40)  p40T=T
                        (p45)  p45T=T
                        (p50)  p50T=T
                        (p55)  p55T=T
                        (p60)  p60T=T
                        (p80)  p80T=T
                        [w=fhat] , by(y) ;

               #delimit cr


       **SAVE data set with the values of the percentiles for total earnings


         sort y
         keep y p*
         tempfile tps
         save `tps'

      restore

      **Merge on total percentages


     preserve

      sort y
      merge y using `tps'
      drop _merge

      replace fhat = round(fhat,1)


      keep T p* y fhat

      expand fhat

      **Sum of everyone's earnings by year
        bysort y: egen totalT = sum(T)

      **Earnings of top 20%
        bysort y: egen t_80 = sum(T) if T >= p80T

      **Earnings of bottom 20%
        bysort y: egen t_20 = sum(T) if T <= p20T

      **Earnings of middle 20%
        bysort y: egen t_4060 = sum(T) if T >  p20T & T <  p80T


      collapse t_80 t_20 t_4060 totalT, by(y)

      foreach num of numlist 80 20 4060 {
       gen p`num' = t_`num'/totalT
      }


      gen k8020 = p80/p20
      gen k8050 = p80/p4060
      gen k5020 = p4060/p20

      sort y
      tempfile kuz
      save `kuz'


           list k5020 k8050 k8020 if y == 1968 | y == 2004



           ***Save these variables for later use***

               foreach x in k5020 k8050 k8020 {
                 rename `x' `x'NZ
               }

               sort y

               tempfile ratioNZ
               save `ratioNZ'



           restore




      ******************************
      *** CHANGE IN CV           ***
      ******************************


           preserve

            foreach var of varlist oHscale oWscale fwag {
              foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {

                quietly summarize `var' [aw=fhat] if y == `num'
                scalar def  V`var'`num'  = (r(sd))
                scalar def  M`var'`num' = (r(mean))
                scalar def CV`var'`num' = V`var'`num'/M`var'`num'

            }
            }

            display CVfwag1968
            display CVfwag2004

       #delimit ;


          *OBSERVED CHANGE IN CV ;

          foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {  ;

          scalar def a = MoHscale`num'/Mfwag`num' ;
          scalar def b = MoWscale`num'/Mfwag`num' ;

          scalar def const_CV2`num' = (a^2*CVoHscale`num'^2) +
                                    (b^2*CVoWscale`num'^2) +
                                    (2*r`num'*a*b*CVoHscale`num'*CVoWscale`num') ;

          gen CVf`num' = sqrt(const_CV2`num') ;


          } ;


          #delimit cr


          forvalues j = 1968(4)2004 {
            gen pchh`j' = (CVoHscale`j'-CVoHscale1968)/CVoHscale1968
            gen pchw`j' = (CVoWscale`j'-CVoWscale1968)/CVoWscale1968
            gen pchf`j' = (CVfwag`j'-CVfwag1968)/CVfwag1968
          }

         keep in 1
         keep pch* CVf*
         gen id = 1
         reshape long pchh pchw pchf CVf  , i(id) j(y)


         lab var pchh "CV, husbands"
         lab var pchw "CV, wives"
         lab var pchf "CV, couples"

         ***Predicted Percentage Change in CVs***

         #delimit ;
         twoway connected pchh pchw pchf y, /*yscale(r(1.4 2.0)) c(l) clstyle(p2 p2 p2 p2 p2 p2) ylabel(1.4(.2)2.0)*/
                                         mcolor(blue red brown purple lime gs4)
                                         clcolor(blue red brown purple lime gs4)
                                         xlabel(#15)
                                         title("Percent Change in CV by Source") sub("Predicted NZ")
                                         ytitle("% Change (Base Year = 1968)") xtitle("year") ;
         #delimit cr





      ***Save these variables for later use***

          rename CVf cvNZ
          sort y

          tempfile cvNZ
          save `cvNZ'

         restore




      drop fhat r???? f03*






**************************************************************
*                                                            *
* STEP 4.  Now run a model without any assocation at all     *
*                                                            *
*          I get some change in the correlation because      *
*          the association is correlated with changes in the *
*          margainals.                                       *
*                                                            *
**************************************************************



**************************
* NO HW                  *
**************************



          gen f03 = freq

          #delimit ;
          xi: glm f03 i.Wp*i.y i.Hp*i.y                          /*WpY HpY*/
                                   , family(poisson) link(log) offset(neglnzi) ;
          #delimit cr


          matrix b=e(b)
          svmat b, n(eqcol)

          predict fhat, nooffset





   **********************************************************************
   ***DESCRIPTIVES USING PREDICTED VALUES --- NO HW                   ***
   **********************************************************************


      sort Hp Wp y


      foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
       quietly corr oWscale oHscale [aw=fhat] if y == `num'
       quietly gen r`num' = r(rho)
      }


      preserve


      keep r????
      collapse r????

      gen id = _n
      reshape long r, i(id) j(y)


      ********************
      ***Predicted Corr***
      ********************


          #delimit ;
          twoway connected r y, yscale(r(-.1 .25)) c(l) clstyle(p2 p2 p2 p2 p2 p2) ylabel(-.1(.05).25)
                                          mcolor(blue red brown purple lime gs4)
                                          clcolor(blue red brown purple lime gs4)
                                          xlabel(#15)
                                          title("Predicted Corr Between Spouses' Earnings") sub("HW")
                                          ytitle("Predicted Corr") xtitle("year") ;
          #delimit cr


          list y r if y == 1968 | y == 2004



      ***Save these variables for later use***

          rename r rHW
          sort y

          tempfile corrHW
          save `corrHW'


      restore



      ******************************
      *** 80/50 and 80/20 ratios ***
      ******************************


             preserve

               #delimit ;


               collapse (p10)  p10T=T
                        (p20)  p20T=T
                        (p40)  p40T=T
                        (p45)  p45T=T
                        (p50)  p50T=T
                        (p55)  p55T=T
                        (p60)  p60T=T
                        (p80)  p80T=T
                        [w=fhat] , by(y) ;

               #delimit cr


       **SAVE data set with the values of the percentiles for total earnings


         sort y
         keep y p*
         tempfile tps
         save `tps'

      restore

      **Merge on total percentages


     preserve

      sort y
      merge y using `tps'
      drop _merge

      replace fhat = round(fhat,1)


      keep T p* y fhat

      expand fhat

      **Sum of everyone's earnings by year
        bysort y: egen totalT = sum(T)

      **Earnings of top 20%
        bysort y: egen t_80 = sum(T) if T >= p80T

      **Earnings of bottom 20%
        bysort y: egen t_20 = sum(T) if T <= p20T

      **Earnings of middle 20%
        bysort y: egen t_4060 = sum(T) if T >  p20T & T <  p80T


      collapse t_80 t_20 t_4060 totalT, by(y)

      foreach num of numlist 80 20 4060 {
       gen p`num' = t_`num'/totalT
      }


      gen k8020 = p80/p20
      gen k8050 = p80/p4060
      gen k5020 = p4060/p20

      sort y
      tempfile kuz
      save `kuz'


           list k5020 k8050 k8020 if y == 1968 | y == 2004



           ***Save these variables for later use***

               foreach x in k5020 k8050 k8020 {
                 rename `x' `x'HW
               }

               sort y

               tempfile ratioHW
               save `ratioHW'



           restore




      ******************************
      *** CHANGE IN CV           ***
      ******************************


           preserve

            foreach var of varlist oHscale oWscale fwag {
              foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {

                quietly summarize `var' [aw=fhat] if y == `num'
                scalar def  V`var'`num'  = (r(sd))
                scalar def  M`var'`num' = (r(mean))
                scalar def CV`var'`num' = V`var'`num'/M`var'`num'

            }
            }

            display CVfwag1968
            display CVfwag2004

       #delimit ;


          *OBSERVED CHANGE IN CV ;

          foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {  ;

          scalar def a = MoHscale`num'/Mfwag`num' ;
          scalar def b = MoWscale`num'/Mfwag`num' ;

          scalar def const_CV2`num' = (a^2*CVoHscale`num'^2) +
                                    (b^2*CVoWscale`num'^2) +
                                    (2*r`num'*a*b*CVoHscale`num'*CVoWscale`num') ;

          gen CVf`num' = sqrt(const_CV2`num') ;


          } ;


          #delimit cr


          forvalues j = 1968(4)2004 {
            gen pchh`j' = (CVoHscale`j'-CVoHscale1968)/CVoHscale1968
            gen pchw`j' = (CVoWscale`j'-CVoWscale1968)/CVoWscale1968
            gen pchf`j' = (CVfwag`j'-CVfwag1968)/CVfwag1968
          }

         keep in 1
         keep pch* CVf*
         gen id = 1
         reshape long pchh pchw pchf CVf  , i(id) j(y)


         lab var pchh "CV, husbands"
         lab var pchw "CV, wives"
         lab var pchf "CV, couples"

         ***Predicted Percentage Change in CVs***

         #delimit ;
         twoway connected pchh pchw pchf y, /*yscale(r(1.4 2.0)) c(l) clstyle(p2 p2 p2 p2 p2 p2) ylabel(1.4(.2)2.0)*/
                                         mcolor(blue red brown purple lime gs4)
                                         clcolor(blue red brown purple lime gs4)
                                         xlabel(#15)
                                         title("Percent Change in CV by Source") sub("Predicted HW")
                                         ytitle("% Change (Base Year = 1968)") xtitle("year") ;
         #delimit cr





      ***Save these variables for later use***

          rename CVf cvHW
          sort y

          tempfile cvHW
          save `cvHW'

         restore




      drop fhat r???? f03*



**************************************************************
*                                                            *
* STEP 5.  Calculate the observed measures for comparison.   *
*                                                            *
**************************************************************



   ****************************************************************
   ***DESCRIPTIVES USING PREDICTED VALUES --- OBSERVED          ***
   ****************************************************************



      foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
       quietly corr oWscale oHscale [aw=WEIGHT] if y == `num'
       quietly gen r`num' = r(rho)
      }


      preserve


      keep r????
      collapse r????

      gen id = _n
      reshape long r, i(id) j(y)


      ********************
      ***Predicted Corr***
      ********************


          #delimit ;
          twoway connected r y, yscale(r(-.1 .25)) c(l) clstyle(p2 p2 p2 p2 p2 p2) ylabel(-.1(.05).25)
                                          mcolor(blue red brown purple lime gs4)
                                          clcolor(blue red brown purple lime gs4)
                                          xlabel(#15)
                                          title("Predicted Corr Between Spouses' Earnings") sub("Variable D")
                                          ytitle("Predicted Corr") xtitle("year") ;
          #delimit cr


          list y r if y == 1968 | y == 2004


      ***Save these variables for later use***

          rename r rOB
          sort y

          tempfile corrOB
          save `corrOB'


      restore



      ******************************
      *** 80/50 and 80/20 ratios ***
      ******************************



             preserve

               #delimit ;


               collapse (p10)  p10T=T
                        (p20)  p20T=T
                        (p40)  p40T=T
                        (p45)  p45T=T
                        (p50)  p50T=T
                        (p55)  p55T=T
                        (p60)  p60T=T
                        (p80)  p80T=T
                        [w=WEIGHT] , by(y) ;

               #delimit cr


       **SAVE data set with the values of the percentiles for total earnings


         sort y
         keep y p*
         tempfile tps
         save `tps'

      restore

      **Merge on total percentages


     preserve

      sort y
      merge y using `tps'
      drop _merge

      replace WEIGHT = round(WEIGHT,1)


      keep T p* y WEIGHT

      expand WEIGHT

      **Sum of everyone's earnings by year
        bysort y: egen totalT = sum(T)

      **Earnings of top 20%
        bysort y: egen t_80 = sum(T) if T >= p80T

      **Earnings of bottom 20%
        bysort y: egen t_20 = sum(T) if T <= p20T

      **Earnings of middle 20%
        bysort y: egen t_4060 = sum(T) if T >  p20T & T <  p80T


      collapse t_80 t_20 t_4060 totalT, by(y)

      foreach num of numlist 80 20 4060 {
       gen p`num' = t_`num'/totalT
      }


      gen k8020 = p80/p20
      gen k8050 = p80/p4060
      gen k5020 = p4060/p20

      sort y
      tempfile kuz
      save `kuz'


           list k5020 k8050 k8020 if y == 1968 | y == 2004



           ***Save these variables for later use***

               foreach x in k5020 k8050 k8020 {
                 rename `x' `x'OB
               }

               sort y

               tempfile ratioOB
               save `ratioOB'



           restore






      ******************************
      *** CHANGE IN CV           ***
      ******************************



           preserve

            foreach var of varlist oHscale oWscale fwag {
              foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {


                *Aweights give a different estimate of the variance than fweights. My weight
                *variable has decimal places, however, so I can't use fweights.  I weights
                *give the same estimate of the variance as fweights. Use iweights here.

                quietly summarize `var' [iw=WEIGHT] if y == `num'
                scalar def  V`var'`num'  = (r(sd))
                scalar def  M`var'`num' = (r(mean))
                scalar def CV`var'`num' = V`var'`num'/M`var'`num'

            }
            }

            display CVfwag1968
            display CVfwag2004

       #delimit ;


          *OBSERVED CHANGE IN CV ;

          foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {  ;

          scalar def a = MoHscale`num'/Mfwag`num' ;
          scalar def b = MoWscale`num'/Mfwag`num' ;

          scalar def const_CV2`num' = (a^2*CVoHscale`num'^2) +
                                    (b^2*CVoWscale`num'^2) +
                                    (2*r`num'*a*b*CVoHscale`num'*CVoWscale`num') ;

          gen CVf`num' = sqrt(const_CV2`num') ;

          scalar def const_CV2`num' = (a^2*CVoHscale`num'^2) +
                                    (b^2*CVoWscale`num'^2) +
                                    (2*r1968*a*b*CVoHscale`num'*CVoWscale`num') ;

          gen cf1_CVf`num' = sqrt(const_CV2`num') ;



          } ;


         *Grouped data: no change in correlation.  For Appendix Table B1. ;

         display cf1_CVf1968 ;
         display cf1_CVf2004 ;



          #delimit cr


          forvalues j = 1968(4)2004 {
            gen pchh`j' = (CVoHscale`j'-CVoHscale1968)/CVoHscale1968
            gen pchw`j' = (CVoWscale`j'-CVoWscale1968)/CVoWscale1968
            gen pchf`j' = (CVfwag`j'-CVfwag1968)/CVfwag1968
          }

         keep in 1
         keep pch* CVf*
         gen id = 1
         reshape long pchh pchw pchf CVf  , i(id) j(y)


         lab var pchh "CV, husbands"
         lab var pchw "CV, wives"
         lab var pchf "CV, couples"

         ***Predicted Percentage Change in CVs***

         #delimit ;
         twoway connected pchh pchw pchf y, /*yscale(r(1.4 2.0)) c(l) clstyle(p2 p2 p2 p2 p2 p2) ylabel(1.4(.2)2.0)*/
                                         mcolor(blue red brown purple lime gs4)
                                         clcolor(blue red brown purple lime gs4)
                                         xlabel(#15)
                                         title("Percent Change in CV by Source") sub("OB")
                                         ytitle("% Change (Base Year = 1968)") xtitle("year") ;
         #delimit cr





      ***Save these variables for later use***

          rename CVf cvOB
          sort y

          tempfile cvOB
          save `cvOB'




         restore




      drop WEIGHT r????










**************************************************************
*                                                            *
* STEP 7.  Merge all of the temporary files together that    *
*          contain the predicted correlations and inequality *
*          measures.                                         *
*                                                            *
*          Graph.                                            *
*                                                            *
**************************************************************


clear

#delimit ;
xmerge y using `corrFDSD'   `corrZB' `corrNZ' `corrHW' `corrOB'
               `ratioFDSD'  `ratioZB' `ratioNZ' `ratioHW' `ratioOB'
               `cvFDSD'     `cvZB' `cvNZ' `cvHW' `cvOB'            ;

#delimit cr


*save "U:\papers and projects\earnings associations\dta\decomp_mcohab.dta", replace



    cd "U:\papers and projects\earnings associations\graphs"



   #delimit ;
   twoway connected rOB rFDSD rZB rNZ rHW y,
                            /*     yscale(log r(.4 1.1)) c(l) clstyle(p2 p2 p2 p2 p2 p2) ylabel(.4(.1)1.1) */
                                   mcolor(blue red brown purple lime gs4)
                                   clcolor(blue red brown purple lime gs4)
                                   xlabel(#15)
                                   title("Predicted change in corr") sub("")
                                   ytitle("Corr") xtitle("year") ;
   #delimit cr

         *graph export decomp_mcohab1.wmf, replace



preserve
keep cvOB cvFDSD cvZB cvNZ cvHW id y
reshape wide cvOB cvFDSD cvZB cvNZ cvHW, i(id) j(y)
display "output YEAR:    1968                   2004"
display "output CV OBS   "    cvOB1968   "              "   cvOB2004
display "output CV FDSD  "    cvFDSD1968 "              "   cvFDSD2004
display "output CV ZB    "    cvZB1968   "              "   cvZB2004
display "output CV NZ    "    cvNZ1968   "              "   cvNZ2004
display "output CV HW    "    cvHW1968   "              "   cvHW2004
restore

preserve
keep k8020OB k8020FDSD k8020ZB k8020NZ k8020HW id y
reshape wide k8020OB k8020FDSD k8020ZB k8020NZ k8020HW, i(id) j(y)
display "output YEAR:    1968                   2004"
display "output 8020 OBS   "    k8020OB1968   "              "   k8020OB2004
display "output 8020 FDSD  "    k8020FDSD1968 "              "   k8020FDSD2004
display "output 8020 ZB    "    k8020ZB1968   "              "   k8020ZB2004
display "output 8020 NZ    "    k8020NZ1968   "              "   k8020NZ2004
display "output 8020 HW    "    k8020HW1968   "              "   k8020HW2004
restore


preserve
keep k8050OB k8050FDSD k8050ZB k8050NZ k8050HW id y
reshape wide k8050OB k8050FDSD k8050ZB k8050NZ k8050HW, i(id) j(y)
display "output YEAR:    1968                   2004"
display "output 8050 OBS   "    k8050OB1968   "              "   k8050OB2004
display "output 8050 FDSD  "    k8050FDSD1968 "              "   k8050FDSD2004
display "output 8050 ZB    "    k8050ZB1968   "              "   k8050ZB2004
display "output 8050 NZ    "    k8050NZ1968   "              "   k8050NZ2004
display "output 8050 HW    "    k8050HW1968   "              "   k8050HW2004
restore

preserve
keep k5020OB k5020FDSD k5020ZB k5020NZ k5020HW id y
reshape wide k5020OB k5020FDSD k5020ZB k5020NZ k5020HW, i(id) j(y)
display "output YEAR:    1968                   2004"
display "output 5020 OBS   "    k5020OB1968   "              "   k5020OB2004
display "output 5020 FDSD  "    k5020FDSD1968 "              "   k5020FDSD2004
display "output 5020 ZB    "    k5020ZB1968   "              "   k5020ZB2004
display "output 5020 NZ    "    k5020NZ1968   "              "   k5020NZ2004
display "output 5020 HW    "    k5020HW1968   "              "   k5020HW2004
restore


***1992******

preserve
keep cvOB cvFDSD cvZB cvNZ cvHW id y
reshape wide cvOB cvFDSD cvZB cvNZ cvHW, i(id) j(y)
display "output YEAR:    1968                   1992"
display "output CV OBS   "    cvOB1968   "              "   cvOB1992
display "output CV FDSD  "    cvFDSD1968 "              "   cvFDSD1992
display "output CV ZB    "    cvZB1968   "              "   cvZB1992
display "output CV NZ    "    cvNZ1968   "              "   cvNZ1992
display "output CV HW    "    cvHW1968   "              "   cvHW1992
restore

preserve
keep k8020OB k8020FDSD k8020ZB k8020NZ k8020HW id y
reshape wide k8020OB k8020FDSD k8020ZB k8020NZ k8020HW, i(id) j(y)
display "output YEAR:    1968                   1992"
display "output 8020 OBS   "    k8020OB1968   "              "   k8020OB1992
display "output 8020 FDSD  "    k8020FDSD1968 "              "   k8020FDSD1992
display "output 8020 ZB    "    k8020ZB1968   "              "   k8020ZB1992
display "output 8020 NZ    "    k8020NZ1968   "              "   k8020NZ1992
display "output 8020 HW    "    k8020HW1968   "              "   k8020HW1992
restore


preserve
keep k8050OB k8050FDSD k8050ZB k8050NZ k8050HW id y
reshape wide k8050OB k8050FDSD k8050ZB k8050NZ k8050HW, i(id) j(y)
display "output YEAR:    1968                   1992"
display "output 8050 OBS   "    k8050OB1968   "              "   k8050OB1992
display "output 8050 FDSD  "    k8050FDSD1968 "              "   k8050FDSD1992
display "output 8050 ZB    "    k8050ZB1968   "              "   k8050ZB1992
display "output 8050 NZ    "    k8050NZ1968   "              "   k8050NZ1992
display "output 8050 HW    "    k8050HW1968   "              "   k8050HW1992
restore

preserve
keep k5020OB k5020FDSD k5020ZB k5020NZ k5020HW id y
reshape wide k5020OB k5020FDSD k5020ZB k5020NZ k5020HW, i(id) j(y)
display "output YEAR:    1968                   1992"
display "output 5020 OBS   "    k5020OB1968   "              "   k5020OB1992
display "output 5020 FDSD  "    k5020FDSD1968 "              "   k5020FDSD1992
display "output 5020 ZB    "    k5020ZB1968   "              "   k5020ZB1992
display "output 5020 NZ    "    k5020NZ1968   "              "   k5020NZ1992
display "output 5020 HW    "    k5020HW1968   "              "   k5020HW1992
restore






    cd "U:\papers and projects\earnings associations\graphs"

 twoway connected cvOB cvFDSD  cvZB cvNZ cvHW y
         *graph export decomp_mcohab2.wmf, replace

 twoway connected k8020OB k8020FDSD  k8020ZB k8020NZ k8020HW  y
         *graph export decomp_mcohab3.wmf, replace

 twoway connected k8050OB k8050FDSD  k8050ZB k8050NZ k8050HW  y
         *graph export decomp_mcohab4.wmf, replace

 twoway connected k5020OB k5020FDSD  k5020ZB k5020NZ k5020HW  y
         *graph export decomp_mcohab5.wmf, replace


log close

