*desc_income.do
capture log close
log using "U:\papers and projects\earnings associations\do\sensitivity_rr\desc_income.log", replace
set more 1
clear
program drop _all
set mem 500M

set matsize 3000


#delimit cr



   use "U:\papers and projects\earnings associations\dta\topcode.dta", clear



     ***This part deflates the weights so that the original
     ***sample size is maintained


        bysort y: egen double sumwgt = sum(WEIGHT)
        bysort y: gen N = _N


        bysort y: gen double deflate = N/sumwgt



        *preserve original weight variables
         rename WEIGHT oweight

        bysort y: gen double WEIGHT = oweight*deflate



***Year categories***

    #delimit ;
    recode y  1968/1971 = 1968 1972/1975 = 1972 1976/1979 = 1976 1980/1983 = 1980
              1984/1987 = 1984 1988/1991 = 1988 1992/1995 = 1992 1996/1999 = 1996
              2000/2003 = 2000 2004/2006 = 2004;
    #delimit cr


***RENAME SOME INCOME VARIABLES SO THAT SAME CODE I'VE USED PREVIOUSLY WORKS

drop W H

rename Ti T
rename Wi W
rename Hi H



*******************************************************
* MEASURES OF INCOME INEQUALITY AMONG MARRIED COUPLES *
*******************************************************

             preserve

               #delimit ;


               collapse (p10)  p10T=T
                        (p15)  p15T=T
                        (p20)  p20T=T
                        (p25)  p25T=T
                        (p30)  p30T=T
                        (p40)  p40T=T
                        (p45)  p45T=T
                        (p50)  p50T=T
                        (p55)  p55T=T
                        (p60)  p60T=T
                        (p70)  p70T=T
                        (p75)  p75T=T
                        (p80)  p80T=T
                        (p85)  p85T=T
                        (p90)  p90T=T [w=oweight] , by(y) ;

               #delimit cr

                  foreach num of numlist 90 85 75 55 50 25 15 10 {
                   replace p`num'T = p`num'T/1000
                  }

                  foreach num of numlist 90 85 75 55 50 25 15 10 {
                   quietly gen  pchg`num' =  ((p`num'T - p`num'T[1])/p`num'T[1])*100
                  }

                  lab var pchg90 "90th"
                  lab var pchg75 "75th"
                  lab var pchg50 "median"
                  lab var pchg25 "25th"
                  lab var pchg10 "10th"

                  #delimit ;
                  twoway connected pchg90 pchg75 pchg50 pchg25 pchg10 y, c(l)
                  scheme(s1color)
                  msymbol(S + X D Th)
                  msize(medium medium medsmall medsmall) ysc(r(-20 60))  ylabel(-20(10)60, grid)
                  clpattern(llll) clcolor(gs0 gs0 gs0 gs0 gs0) mcolor(gs0 gs0 gs0 gs0 gs0) graphregion(fcolor(gs16)) plotregion(style(none))
                  xlabel(#15)   title(" ", size(medlarge) color(gs0)) sub(" ")
                  ytitle("% Change since 1967") xtitle("Year")
                  title("Percentage Change in Real Wage and Salary Income by Percentile") sub("Husbands and Wives Age 22-55")
                  note("SOURCE: March Current Population Survey (CPS).")
                   ;

                 #delimit cr

                 cd "U:\papers and projects\earnings associations\graphs"
                 graph export desc_income_1.wmf, replace


                 **Comparisons with median.

                  sort y

                  foreach num of numlist 90 75 25 10 {
                   quietly gen  p`num'_50 =  ((p`num'T/p50T)/(p`num'T[1]/p50T[1]))*100
                  }

              restore
              preserve

        #delimit ;


               collapse (p20)  p20T=T
                        (p50)  p50T=T
                        (p60)  p60T=T /*51-60*/
                        (p80)  p80T=T
                        (p90)  p90T=T [iw=oweight] , by(y) ;

        #delimit cr

                   quietly gen  p80_20 =  ((p80T/p20T)/(p80T[1]/p20T[1]))*100
                   quietly gen  p50_20 =  ((p50T/p20T)/(p50T[1]/p20T[1]))*100
                   quietly gen  p80_50 =  ((p80T/p50T)/(p80T[1]/p50T[1]))*100

                   quietly gen  f80_20 =  (p80T/p20T)
                   quietly gen  f50_20 =  (p50T/p20T)
                   quietly gen  f80_50 =  (p80T/p50T)


                  lab var p80_20 "80/20 ratio"
                  lab var p80_50 "80/50 ratio"
                  lab var p50_20 "50/20 ratio"




                  *estimates of change in ratios using individual-level data for Supplementary Table B1.

                   list f80_20 f50_20 f80_50 y






                  #delimit ;
              twoway connected p80_20 p80_50 p50_20 y, c(l)
                                              mlcolor(gs0 gs0 gs0 gs0 gs0)
                                              mfcolor(gs12 gs0 gs0 gs0 gs0)
                                              clcolor(gs0 gs4 gs0 gs4 gs0)
                                              msize(medium medium medium medium medium)
                                              msymbol(s Oh t X o)
                                              ysc(r(60 140))  ylabel(60(10)140, labsize(*.9) labgap(.01))
                                              yline(100, lcolor(black))
                                              l1title("Index 1967-1971=100", size(*.9))
                                              scheme(s1color)
                                              graphregion(fcolor(gs16)) plotregion(style(none))
                                              title(" ", size(medlarge) color(gs0)) sub(" ")
                  xlabel(1968 `" " 1967-" "1970" "' 1972 `" " 1971-" "1974" "'  1976 `" " 1975-" "1978" "'
                         1980 `" " 1979-" "1982" "' 1984 `" " 1983-" "1986" "'  1988 `" " 1987-" "1991" "'
                         1992 `" " 1991-" "1994" "' 1996 `" " 1995-" "1998" "'  2000 `" " 1999-" "2002" "'  2004 `" " 2003-" "2005" "' , labsize(*.9))
                                              xtitle("Year") legend(rows(2))
                                              ;
                 #delimit cr


                 cd "U:\papers and projects\earnings associations\graphs"
                 graph export desc_income_2.wmf, replace fontface(garamond)


                 **Comparisons with each other.




                 list p80_20 p50_20 p80_50 y if y == 2001
                 list p80_20 p50_20 p80_50 y if y == 1996
                 list f80_20 f50_20 f80_50 y if y == 1968
                 list f80_20 f50_20 f80_50 y if y == 2001


                 cd "U:\papers and projects\earnings associations\graphs"
                 graph export desc_income_4.wmf, replace

                 keep p* y
                 sort y
                 tempfile ratios
                 save `ratios'

       **SAVE data set with the values of the percentiles for total-earnings


         sort y
         keep y p20T p50T p90T p80T p60T
         tempfile tps
         save `tps'



            restore



        *****************
        *  CV BY SOURCE *
        *****************


              ************
              * EVERYONE *
              ************



              *The corr is the same whether I use fweight or aweights

              foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
               quietly corr H W [aw=oweight] if y == `num'
               quietly gen r`num' = r(rho)
              }


               gen wW = W if W > 0


              *the standard deviation differs slightly using aweights. Use fweights
              *here.

               foreach var of varlist H W wW T {
                 foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {

                   quietly summarize `var' [fw=oweight] if y == `num'
                   scalar def  V`var'`num'  = (r(sd))
                   scalar def  M`var'`num' = (r(mean))
                   scalar def CV`var'`num' = V`var'`num'/M`var'`num'

               }
               }


             **Numbers for Supplementary Table B1
               display CVT1968
               display CVT2004


               #delimit ;

               *OBSERVED CHANGE IN CV ;

               foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {  ;

               scalar def a = MH`num'/MT`num' ;
               scalar def b = MW`num'/MT`num' ;

               scalar def const_CV2`num' = (a^2*CVH`num'^2) +
                                         (b^2*CVW`num'^2) +
                                         (2*r`num'*a*b*CVH`num'*CVW`num') ;

               gen CVf`num' = sqrt(const_CV2`num') ;


               } ;


               display CVf1968 ;
               display CVf2004 ;




                 *COUNTERFACTUAL 1: no change in the correlation btwn spouses' wages ;

                 forvalues i = 1968(4)2004 { ;

                 scalar def a = MH`i'/MT`i' ;
                 scalar def b = MW`i'/MT`i' ;

                 scalar def const_CV2`i' = (a^2*CVH`i'^2) +
                                           (b^2*CVW`i'^2) +
                                           (2*r1968*a*b*CVH`i'*CVW`i') ;

                 gen cf1_CVf`i' = sqrt(const_CV2`i') ;


                 } ;


             **Numbers for Supplementary table B1 "CV, less changes in correlation" ;
               display cf1_CVf1968 ;
               display cf1_CVf2004 ;



               #delimit cr


               forvalues j = 1968(4)2004 {
                 gen pchh`j' = (CVH`j'/CVH1968)*100
                 gen pchw`j' = (CVW`j'/CVW1968)*100
                 gen pchww`j'= (CVwW`j'/CVwW1968)*100
                 gen pchf`j' = (CVT`j'/CVT1968)*100
                 gen pcf1`j' = (cf1_CVf`j'/cf1_CVf1968)*100
               }



              preserve

              keep in 1
              keep pch* pcf1*
              gen id = 1
              reshape long pchh pchw pchww pchf pcf1, i(id) j(y)


              lab var pchh  "Husbands"
              lab var pchw  "Wives"
              lab var pchww "Wives (non-zero-earnings)"
              lab var pchf  "Couples"
              lab var pcf1  "Couples, r(H,W) = 1967"


              sort y
              merge y using `ratios'





             ****************
             ****FIGURE 1****
             ****************

    *recode years to medians

    #delimit ;
    recode y  1968=1969.5 1972=1973.5 1976=1977.5 1980=1981.5
              1984=1985.5 1988=1989.5 1992=1993.5 1996=1997.5
              2000=2001.5 2004=2005;
    #delimit cr

              lab var pchf "CV"

                  #delimit ;
              twoway connected p80_20 p50_20 p80_50 pchf y, c(l)
                                              mlcolor(gs0 gs0 gs0 gs0 gs0)
                                              mfcolor(gs12 gs0 gs0 gs0 gs0)
                                              clcolor(gs0 gs4 gs0 gs4 gs0)
                                              msize(medium medium medium medium medium)
                                              msymbol(s Oh t X o)
                                              ysc(r(100 140))  ylabel(100(10)150, labsize(*.9) labgap(.01))
                                              yline(100, lcolor(black))
                                              l1title("Index 1967-1970=100", size(*.9))
                                              scheme(s1color)
                                              graphregion(fcolor(gs16)) plotregion(style(none))
                                              title(" ", size(medlarge) color(gs0)) sub(" ")
                  xlabel(1969.5 `" " 1967-" "1970" "' 1973.5 `" " 1971-" "1974" "'  1977.5 `" " 1975-" "1978" "'
                         1981.5 `" " 1979-" "1982" "' 1985.5 `" " 1983-" "1986" "'  1989.5 `" " 1987-" "1991" "'
                         1993.5 `" " 1991-" "1994" "' 1997.5 `" " 1995-" "1998" "'  2001.5 `" " 1999-" "2002" "'  2005 `" " 2003-" "2005" "', labsize(*.9))
                                              xtitle("Year") legend(rows(2))
                                              ;
                 #delimit cr


                 cd "U:\papers and projects\earnings associations\graphs"
                 graph export desc_income_8.wmf, replace fontface(garamond)




         *Numbers for discussion of Figure 1
          list pchh pchw pchf pcf1 p80_20 p50_20 p80_50 y if y == 2005

          list pchh pchw pchf y if y == 1997.5
          list pchh pchw pchf y if y == 1993.5

            restore





***************
* CORRELATION *
***************



      *I use aweights here.  The same answer is obtained using fweights.


         foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
          quietly corr W H if W ~= 0 & H ~= 0 & y == `num' [aw=oweight]
          quietly gen rwork`num' = r(rho)
           quietly corr W H if                             y == `num' [aw=oweight]
           quietly gen rall`num' = r(rho)
         }


         preserve

         keep in 1
         collapse rwork* rall*

         gen id = 1
         reshape long rwork rall, i(id) j(y)

         lab var rwork "Dual-Earner Couples"
         lab var rall  "All Couples"




      **************
      ***FIGURE 2***
      **************


    *recode years to medians

    #delimit ;
    recode y  1968=1969.5 1972=1973.5 1976=1977.5 1980=1981.5
              1984=1985.5 1988=1989.5 1992=1993.5 1996=1997.5
              2000=2001.5 2004=2005;
    #delimit cr


                #delimit ;
            twoway connected     rall  y, c(l)
                                            mlcolor(gs0 gs0 gs0 gs0 gs0)
                                            mfcolor(gs12 gs0 gs0 gs0 gs0)
                                            clcolor(gs0 gs0 gs0 gs0 gs0)
                                            msize(medium medium medium medium medium)
                                            msymbol(/*s Oh*/ t o)
                                            ysc(r(-.1 .25))  ylabel(-.1(.05).25, labsize(*.9) labgap(.01))
                                            yline(0, lcolor(black))
                                            l1title("Correlation", size(*.9))
                                            scheme(s1color)
                                            graphregion(fcolor(gs16)) plotregion(style(none))
                                            title(" ", size(medlarge) color(gs0)) sub(" ")
                  xlabel(1969.5 `" " 1967-" "1970" "' 1973.5 `" " 1971-" "1974" "'  1977.5 `" " 1975-" "1978" "'
                         1981.5 `" " 1979-" "1982" "' 1985.5 `" " 1983-" "1986" "'  1989.5 `" " 1987-" "1991" "'
                         1993.5 `" " 1991-" "1994" "' 1997.5 `" " 1995-" "1998" "'  2001.5 `" " 1999-" "2002" "'  2005 `" " 2003-" "2005" "', labsize(*.9))
                                            xtitle("Year")
                                            ;
               #delimit cr


               cd "U:\papers and projects\earnings associations\graphs"

         graph export desc_income_10.wmf, replace fontface(garamond)


        *Numbers for discussion of Figure 2
         list rwork rall y



      **Color
                #delimit ;
            twoway connected rall rwork  y, c(l)
                                            mlcolor(blue  red   gs0 gs0)
                                            mfcolor(blue  red    gs0 gs0)
                                            clcolor(blue  red   gs0 gs0)
                                            msize(medlarge  medlarge   medium medium)
                                            msymbol(/*s Oh*/ t O)
                                            ysc(r(-.1 .25))  ylabel(-.1(.05).25, labgap(.01))
                                            yline(0, lcolor(black))
                                            ytitle("Correlation")
                                            scheme(s1color)
                                            graphregion(fcolor(gs16)) plotregion(style(none))
                                            title("", size(medlarge) color(gs0)) sub(" ")
                  xlabel(1969.5 `" " 1967-" "1970" "' 1973.5 `" " 1971-" "1974" "'  1977.5 `" " 1975-" "1978" "'
                         1981.5 `" " 1979-" "1982" "' 1985.5 `" " 1983-" "1986" "'  1989.5 `" " 1987-" "1991" "'
                         1993.5 `" " 1991-" "1994" "' 1997.5 `" " 1995-" "1998" "'  2001.5 `" " 1999-" "2002" "'  2005 `" " 2003-" "2005" "', labsize(*.9))
                                            xtitle("Year")
                                            ;
               #delimit cr


               cd "U:\papers and projects\earnings associations\graphs"

         graph export desc_income_11.wmf, replace


               list y rwork rall



      restore

