*desc_kuznet_mcohab.do
capture log close
log using "U:\papers and projects\earnings associations\do\desc_kuznet_mcohab.log", replace
set more 1
clear
program drop _all
set mem 400M

set matsize 3000


#delimit cr



   use "U:\papers and projects\earnings associations\dta\topcode_mcohab.dta", clear



     ***This part deflates the weights so that the original
     ***sample size is maintained


        bysort y: egen double sumwgt = sum(WEIGHT)
        bysort y: gen N = _N


        bysort y: gen double deflate = N/sumwgt



        *preserve original weight variables
         rename WEIGHT oweight

        bysort y: gen double WEIGHT = oweight*deflate


   keep if y > 1967


   *Year categories

    #delimit ;
    recode y  1968/1971 = 1968 1972/1975 = 1972 1976/1979 = 1976 1980/1983 = 1980
              1984/1987 = 1984 1988/1991 = 1988 1992/1995 = 1992 1996/1999 = 1996
              2000/2003 = 2000 2004/2006 = 2004;
    #delimit cr



rename Te T



***************
* CORRELATION *
***************



      *I use aweights here.  The same answer is obtained using fweights.


       ***MARRIED

         foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
          quietly corr W H if W ~= 0 & H ~= 0 & y == `num' & m == 1 [aw=oweight]
          quietly gen rworkm`num' = r(rho)
           quietly corr W H if                             y == `num' & m == 1 [aw=oweight]
           quietly gen rallm`num' = r(rho)
         }


       ***POOLED

         foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
          quietly corr W H if W ~= 0 & H ~= 0 & y == `num' [aw=oweight]
          quietly gen rworkp`num' = r(rho)
           quietly corr W H if                             y == `num' [aw=oweight]
           quietly gen rallp`num' = r(rho)
         }


         preserve

         keep in 1
         collapse rwork* rall*

         gen id = 1
         reshape long rworkm rworkp rallm rallp, i(id) j(y)


      **************
      ***FIGURE 2***
      **************


    *recode years to medians

    #delimit ;
    recode y  1968=1969.5 1972=1973.5 1976=1977.5 1980=1981.5
              1984=1985.5 1988=1989.5 1992=1993.5 1996=1997.5
              2000=2001.5 2004=2005;
    #delimit cr


            lab var rworkm "Dual-Earners (Married)"
            lab var rworkp "Dual-Earners (Married + POSSLQs)"
            lab var rallm  "All Couples (Married)"
            lab var rallp  "All Couples (Married + POSSLQs)"

                #delimit ;
            twoway connected   rworkm rworkp rallm rallp  y, c(l)
                                            mlcolor(gs0 gs0 gs0 gs0 gs0)
                                            mfcolor(gs12 gs0 gs0 gs0 gs0)
                                            clcolor(gs0 gs0 gs0 gs0 gs0)
                                            msize(medium medium medium medium medium)
                                            msymbol(s Oh Th o)
                                            ysc(r(-.1 .25))  ylabel(-.1(.05).25, labsize(*.9) labgap(.01))
                                            yline(0, lcolor(black))
                                            l1title("Correlation", size(*.9))
                                            scheme(s1color)
                                            graphregion(fcolor(gs16)) plotregion(style(none))
                                            title(" ", size(medlarge) color(gs0)) sub(" ")
                  xlabel(1969.5 `" " 1967-" "1970" "' 1973.5 `" " 1971-" "1974" "'  1977.5 `" " 1975-" "1978" "'
                         1981.5 `" " 1979-" "1982" "' 1985.5 `" " 1983-" "1986" "'  1989.5 `" " 1987-" "1991" "'
                         1993.5 `" " 1991-" "1994" "' 1997.5 `" " 1995-" "1998" "'  2001.5 `" " 1999-" "2002" "'  2005 `" " 2003-" "2005" "', labsize(*.9))
                                            xtitle("Year")
                                            ;
               #delimit cr


               cd "U:\papers and projects\earnings associations\graphs"

         graph export desc_kuznet_mcohab_1.wmf, replace fontface(garamond)


      list

      restore



*******************************************************
* MEASURES OF INCOME INEQUALITY AMONG MARRIED COUPLES *
*******************************************************

             preserve

               #delimit ;


               collapse (p10)  p10T=T
                        (p15)  p15T=T
                        (p20)  p20T=T
                        (p25)  p25T=T
                        (p30)  p30T=T
                        (p40)  p40T=T
                        (p45)  p45T=T
                        (p50)  p50T=T
                        (p55)  p55T=T
                        (p60)  p60T=T
                        (p70)  p70T=T
                        (p75)  p75T=T
                        (p80)  p80T=T
                        (p85)  p85T=T
                        (p90)  p90T=T [w=oweight] , by(y) ;

               #delimit cr


       **SAVE data set with the values of the percentiles for total earnings


         sort y
         keep y p*
         tempfile tps
         save `tps'

      restore

      **Merge on total percentages


      preserve

      sort y
      merge y using `tps'
      drop _merge


      **Earnings of top 20%
        gen t_80 = T if T >= p80T

      **Earnings of bottom 20%
        gen t_20 = T if T <= p20T

      **Earnings of middle 20%
        gen t_4060 = T if T >  p20T & T <  p80T


      collapse(sum) T t_80 t_20 t_4060 [w=oweight], by(y)

      foreach num of numlist 80 20 4060 {
       gen p`num' = t_`num'/T
      }


      gen k8020 = p80/p20
      gen k8050 = p80/p4060
      gen k5020 = p4060/p20

      sort y
      tempfile kuz
      save `kuz'

      **FOR APPENDIX TABLE B1
        list y k8020 k8050 k5020



            restore

        *****************
        *  CV BY SOURCE *
        *****************


              ************
              * EVERYONE *
              ************



              *The corr is the same whether I use fweight or aweights

              foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
               quietly corr H W [aw=oweight] if y == `num'
               quietly gen r`num' = r(rho)
              }


               gen wW = W if W > 0


              *the standard deviation differs slightly using aweights. Use fweights
              *here.

               foreach var of varlist H W wW T {
                 foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {

                   quietly summarize `var' [fw=oweight] if y == `num'
                   scalar def  V`var'`num'  = (r(sd))
                   scalar def  M`var'`num' = (r(mean))
                   scalar def CV`var'`num' = V`var'`num'/M`var'`num'

               }
               }



               #delimit ;

               *OBSERVED CHANGE IN CV ;

               foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {  ;

               scalar def a = MH`num'/MT`num' ;
               scalar def b = MW`num'/MT`num' ;

               scalar def const_CV2`num' = (a^2*CVH`num'^2) +
                                         (b^2*CVW`num'^2) +
                                         (2*r`num'*a*b*CVH`num'*CVW`num') ;

               gen CVf`num' = sqrt(const_CV2`num') ;


               } ;


               display CVf1968 ;
               display CVf2004 ;



               #delimit cr


               forvalues j = 1968(4)2004 {
                 gen pchh`j' = (CVH`j'/CVH1968)*100
                 gen pchw`j' = (CVW`j'/CVW1968)*100
                 gen pchww`j'= (CVwW`j'/CVwW1968)*100
                 gen pchf`j' = (CVT`j'/CVT1968)*100
               }



        *     preserve

              keep in 1
              keep pch*
              gen id = 1
              reshape long pchh pchw pchww pchf, i(id) j(y)


              sort y
              merge y using `kuz'
              drop _merge

              lab var pchh  "Husbands"
              lab var pchw  "Wives"
              lab var pchww "Wives (non-zero earnings)"
              lab var pchf  "Couples"




          sort y

          foreach num of numlist 8020 8050 5020 {
           quietly gen  kp`num' =  (k`num'/k`num'[1])*100
          }


            lab var kp8020 "High-Low Inequality"
            lab var kp8050 "High-Middle Inequality"
            lab var kp5020 "Middle-Low Inequality"


    *recode years to medians

    #delimit ;
    recode y  1968=1969.5 1972=1973.5 1976=1977.5 1980=1981.5
              1984=1985.5 1988=1989.5 1992=1993.5 1996=1997.5
              2000=2001.5 2004=2005;
    #delimit cr

              lab var pchf "CV "


             **FIGURE 1**

             #delimit ;
              twoway connected kp8020 kp5020 kp8050 pchf y, c(l)
                                              mlcolor(gs0 gs0 gs0 gs0 gs0)
                                              mfcolor(black gs0 gs0 gs0 gs0)
                                              clcolor(gs0 black gs0 black gs0)
                                              msize(*1.2 medium medium *1.18)
                                              msymbol(sh O T dh)
                                              ysc(r(100 140))  ylabel(100(20)200, labsize(*.9) labgap(.01))
                                              yline(100, lcolor(black))
                                              l1title("Index 1967-1970=100", size(*.9))
                                              scheme(s1color)
                                              graphregion(fcolor(gs16)) plotregion(style(none))
                                              title(" ", size(medlarge) color(gs0)) sub(" ")
                  xlabel(1969.5 `" " 1967-" "1970" "' 1973.5 `" " 1971-" "1974" "'  1977.5 `" " 1975-" "1978" "'
                         1981.5 `" " 1979-" "1982" "' 1985.5 `" " 1983-" "1986" "'  1989.5 `" " 1987-" "1991" "'
                         1993.5 `" " 1991-" "1994" "' 1997.5 `" " 1995-" "1998" "'  2001.5 `" " 1999-" "2002" "'  2005 `" " 2003-" "2005" "', labsize(*.9))
                                              xtitle("Year")


;
                 #delimit cr


                 cd "U:\papers and projects\earnings associations\graphs"
                 graph export desc_kuznet_mcohab_2.wmf, replace fontface(Arial)


list y pchf kp*

