*mtest_unlogged.do
capture log close
log using "U:\papers and projects\earnings associations\do\sensitivity_rr\mtest_unlogged.log", replace
set more 1
clear
program drop _all
set mem 500M
set matsize 3000



#delimit cr



   use "U:\papers and projects\earnings associations\dta\earn_tab_20_ties.dta", clear


   *Year categories

    #delimit ;
    recode y  1968/1971 = 1968 1972/1975 = 1972 1976/1979 = 1976 1980/1983 = 1980
              1984/1987 = 1984 1988/1991 = 1988 1992/1995 = 1992 1996/1999 = 1996
              2000/2003 = 2000 2004/2006 = 2004 ;
    #delimit cr


    collapse (sum) freq WEIGHT (mean) Wscale Hscale, by(y Hp Wp)


    *There should be 21x21x11 == 4410 cells in the table.  There are.

     display _N

      summarize Wscale [w=freq]
      summarize Hscale [w=freq]


    **LOGGED AN NON-LOGGED INCOME VARIABLES


      gen oWscale = Wscale
      gen oHscale = Hscale

      replace Wscale = ln(Wscale) if Wscale ~= 0
      replace Hscale = ln(Hscale) if Hscale ~= 0




    **UA STANDARDIZED NON-LOGGED INCOME


      expand freq


      foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
        quietly egen zoWscale`num' = std(oWscale) if /*oWscale ~= 0 &*/  y == `num'
        quietly egen zoHscale`num' = std(oHscale) if /*oHscale ~= 0 &*/  y == `num'
      }


      gen zoWscale = 0
      gen zoHscale = 0


      foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
       quietly replace zoWscale = zoWscale`num' if y == `num'
       quietly replace zoHscale = zoHscale`num' if y == `num'
      }


      gen ua_std_exp = zoWscale*zoHscale

      drop zo*



    **UA STANDARDIZED LOGGED INCOME




      foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
        quietly egen zWscale`num' = std(Wscale) if Wscale ~= 0 &  y == `num'
        quietly egen zHscale`num' = std(Hscale) if Hscale ~= 0 &  y == `num'
      }

      gen zWscale = 0
      gen zHscale = 0

      foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
       quietly replace zWscale = zWscale`num' if y == `num' & Wscale ~= 0
       quietly replace zHscale = zHscale`num' if y == `num' & Hscale ~= 0
      }


      gen ua_std_ln = zWscale*zHscale



     collapse (mean) freq WEIGHT oWscale oHscale Wscale Hscale ua_std_ln ua_std_exp, by(y Hp Wp)


      *Make sure this collapse worked
      summarize oWscale [w=freq]
      summarize oHscale [w=freq]





  #delimit ;

   ******************
   * WEIGHTING CODE *
   ****************** ;


   ***To weight the data, follow Agresti page 391 section 9.7.5.

      zi = the total weighted frequency divided by the cell
      count.  In my case, this is:

      WEIGHT/freq = zi

      Loglinear models for the weighted expected frequencies
      (zi*mui = mui/ti) with ti = 1/zi expresses the model as
      a standard loglinear model for logmui with offset
      (logti = -logzi).

      What this means is the offset is equal to:

      -ln(zi)

      crs 2/25/04 ;


   #delimit cr


   gen zi      = (WEIGHT/freq)
   gen neglnzi = -ln(zi)


  *Deal with zero cells
   replace neglnzi = 0 if neglnzi == .


*******************************
* CHECK SAMPLE SIZE AND CELLS *
*******************************

tab y
tab y [w=freq]



*********************
* VARIABLE CREATION *
*********************




gen ua = Wscale*Hscale



gen hypi = (Hscale > Wscale)
gen hypp = (Hp > Wp)

gen wz = (Wp == 0 & Hp > 0)
gen hz = (Hp == 0 & Wp > 0)
gen dc0 = (wz+hz)

      quietly gen hzC = 0
      quietly gen wzC = 0

      quietly foreach num of numlist 5(5)100 {
       quietly replace hzC = `num' if (hz == 1 & Wp == `num')
       quietly replace wzC = `num' if (wz == 1 & Hp  == `num')
      }




gen hs2 = (Hscale*Hscale)
gen ws2 = (Wscale*Wscale)
gen Hp2 = (Hp*Hp)
gen Wp2 = (Wp*Wp)

gen hi = (Wscale==Hscale)
gen h  = (Wp == Hp)

   ***Make the crossing variables (Johnson style)

        gen dc20 = (((Wp < 20 & Hp >= 20) | (Hp < 20 & Wp >= 20))  & Wp ~= 0 & Hp ~= 0)
        gen dc30 = (((Wp < 30 & Hp >= 30) | (Hp < 30 & Wp >= 30))  & Wp ~= 0 & Hp ~= 0)
        gen dc40 = (((Wp < 40 & Hp >= 40) | (Hp < 40 & Wp >= 40))  & Wp ~= 0 & Hp ~= 0)
        gen dc50 = (((Wp < 50 & Hp >= 50) | (Hp < 50 & Wp >= 50))  & Wp ~= 0 & Hp ~= 0)
        gen dc60 = (((Wp < 60 & Hp >= 60) | (Hp < 60 & Wp >= 60))  & Wp ~= 0 & Hp ~= 0)
        gen dc70 = (((Wp < 70 & Hp >= 70) | (Hp < 70 & Wp >= 70))  & Wp ~= 0 & Hp ~= 0)
        gen dc80 = (((Wp < 80 & Hp >= 80) | (Hp < 80 & Wp >= 80))  & Wp ~= 0 & Hp ~= 0)
        gen dc90 = (((Wp < 90 & Hp >= 90) | (Hp < 90 & Wp >= 90))  & Wp ~= 0 & Hp ~= 0)
        gen dc100 = (((Wp < 100 & Hp >= 100) | (Hp < 100 & Wp >= 100))  & Wp ~= 0 & Hp ~= 0)



***Distance in deciles, excluding zeros.


   gen d = 0
   replace d = 1 if abs(Wp - Hp) == 5 & Wp ~= 0 & Hp ~= 0
   replace d = 2 if abs(Wp - Hp) == 10 & Wp ~= 0 & Hp ~= 0
   replace d = 3 if abs(Wp - Hp) == 15 & Wp ~= 0 & Hp ~= 0
   replace d = 4 if abs(Wp - Hp) == 20 & Wp ~= 0 & Hp ~= 0
   replace d = 5 if abs(Wp - Hp) == 25 & Wp ~= 0 & Hp ~= 0
   replace d = 6 if abs(Wp - Hp) == 30 & Wp ~= 0 & Hp ~= 0
   replace d = 7 if abs(Wp - Hp) == 35 & Wp ~= 0 & Hp ~= 0
   replace d = 8 if abs(Wp - Hp) == 40 & Wp ~= 0 & Hp ~= 0
   replace d = 9 if abs(Wp - Hp) == 45 & Wp ~= 0 & Hp ~= 0
   replace d =10 if abs(Wp - Hp) == 50 & Wp ~= 0 & Hp ~= 0
   replace d =11 if abs(Wp - Hp) == 55 & Wp ~= 0 & Hp ~= 0
   replace d =12 if abs(Wp - Hp) == 60 & Wp ~= 0 & Hp ~= 0
   replace d =13 if abs(Wp - Hp) == 65 & Wp ~= 0 & Hp ~= 0
   replace d =14 if abs(Wp - Hp) == 70 & Wp ~= 0 & Hp ~= 0
   replace d =15 if abs(Wp - Hp) == 75 & Wp ~= 0 & Hp ~= 0
   replace d =16 if abs(Wp - Hp) == 80 & Wp ~= 0 & Hp ~= 0
   replace d =17 if abs(Wp - Hp) == 85 & Wp ~= 0 & Hp ~= 0
   replace d =18 if abs(Wp - Hp) == 90 & Wp ~= 0 & Hp ~= 0
   replace d =19 if abs(Wp - Hp) == 95 & Wp ~= 0 & Hp ~= 0


***Distance in scale scores, excluding zeros. Distance equals 0 when H = W.

   gen ds = 0

   forvalues i = 1/19 {
    replace ds = abs(Wscale-Hscale) if d == `i'
   }

   forvalues i = 1/19 {
     gen d`i' = (d == `i')
    }


   gen dsq  = d*d


***Distance between husbands and wives scale scores, excluding zeros. Distance is NOT equal to 0 when H = W.

    gen sd_hw = abs(Wscale-Hscale) if Wp ~= 0 & Hp ~= 0
    replace sd_hw = 0 if Wp == 0 | Hp == 0
    gen sd_hw2 = sd_hw*sd_hw
    gen sd_hw3 = sd_hw*sd_hw*sd_hw
    gen sd_hw_exp = abs(oWscale-oHscale) if Wp ~= 0 & Hp ~= 0

    gen sd_hwexp = abs((oWscale/1000)-(oHscale/1000))
    gen sd_hwexp2 = sd_hwexp*sd_hwexp
    gen sd_hwd = sd_hw*d


  sort y Hp Wp
  tempfile full
  save `full'



*    display "AIC  " (-2*e(ll) + 2*e(k))/e(N)




***(1) baseline model


    #delimit ;
    desmat: glm freq Wp*y Hp*y Wp*Hp, family(poisson) link(log) offset(neglnzi) ;
    #delimit cr


    gen dev=e(deviance)
    display dev

    gen df= $S_2
    display df

    egen totfreq=sum(freq)
    gen lnfreq=ln(totfreq)
    gen bic = dev-df*lnfreq

    tab bic
    drop dev-bic

    drop _x*




***(2) baseliue model + UsY


    #delimit ;
    desmat: glm freq Wp*y Hp*y Wp*Hp @ua_std_exp.y, family(poisson) link(log) offset(neglnzi) ;
    #delimit cr


    gen dev=e(deviance)
    display dev

    gen df= $S_2
    display df

    egen totfreq=sum(freq)
    gen lnfreq=ln(totfreq)
    gen bic = dev-df*lnfreq

    tab bic
    drop dev-bic

    drop _x*







***(3) baseliue model + UsY + (Zw)2HY


    #delimit ;
    desmat: glm freq Wp*y Hp*y Wp*Hp @ua_std_exp.y wz.@Hp.y wz.@Hp2.y wz.y, family(poisson) link(log) offset(neglnzi) ;
    #delimit cr


    gen dev=e(deviance)
    display dev

    gen df= $S_2
    display df

    egen totfreq=sum(freq)
    gen lnfreq=ln(totfreq)
    gen bic = dev-df*lnfreq

    tab bic
    drop dev-bic

    drop _x*






log close


