*ua_010508.do
capture log close
log using "U:\papers and projects\earnings associations\do\sensitivity_rr\ua_010509.log", replace
set more 1
clear
program drop _all
set mem 400M



#delimit cr



   use "U:\papers and projects\earnings associations\dta\earn_tab_20_ties.dta", clear


   *Year categories

    #delimit ;
    recode y  1968/1971 = 1968 1972/1975 = 1972 1976/1979 = 1976 1980/1983 = 1980
              1984/1987 = 1984 1988/1991 = 1988 1992/1995 = 1992 1996/1999 = 1996
              2000/2003 = 2000 2004/2006 = 2004 ;
    #delimit cr


    collapse (sum) freq WEIGHT (mean) Wscale Hscale, by(y Hp Wp)


    *There should be 21x21x11 == 4410 cells in the table.  There are.

     display _N

      summarize Wscale [w=freq]
      summarize Hscale [w=freq]


    **LOGGED AN NON-LOGGED INCOME VARIABLES


      gen oWscale = Wscale
      gen oHscale = Hscale

      replace Wscale = ln(Wscale) if Wscale ~= 0
      replace Hscale = ln(Hscale) if Hscale ~= 0




    **UA STANDARDIZED NON-LOGGED INCOME


      expand freq


      foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
        quietly egen zoWscale`num' = std(oWscale) if /*oWscale ~= 0 &*/  y == `num'
        quietly egen zoHscale`num' = std(oHscale) if /*oHscale ~= 0 &*/  y == `num'
      }


      gen zoWscale = 0
      gen zoHscale = 0


      foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
       quietly replace zoWscale = zoWscale`num' if y == `num'
       quietly replace zoHscale = zoHscale`num' if y == `num'
      }


      gen ua_std_exp = zoWscale*zoHscale

      drop zo*



    **UA STANDARDIZED LOGGED INCOME




      foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
        quietly egen zWscale`num' = std(Wscale) if Wscale ~= 0 &  y == `num'
        quietly egen zHscale`num' = std(Hscale) if Hscale ~= 0 &  y == `num'
      }

      gen zWscale = 0
      gen zHscale = 0

      foreach num of numlist 1968 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
       quietly replace zWscale = zWscale`num' if y == `num' & Wscale ~= 0
       quietly replace zHscale = zHscale`num' if y == `num' & Hscale ~= 0
      }


      gen ua_std_ln = zWscale*zHscale



     collapse (mean) freq WEIGHT oWscale oHscale Wscale Hscale ua_std_ln ua_std_exp, by(y Hp Wp)


      *Make sure this collapse worked
      summarize oWscale [w=freq]
      summarize oHscale [w=freq]





  #delimit ;

   ******************
   * WEIGHTING CODE *
   ****************** ;


   ***To weight the data, follow Agresti page 391 section 9.7.5.

      zi = the total weighted frequency divided by the cell
      count.  In my case, this is:

      WEIGHT/freq = zi

      Loglinear models for the weighted expected frequencies
      (zi*mui = mui/ti) with ti = 1/zi expresses the model as
      a standard loglinear model for logmui with offset
      (logti = -logzi).

      What this means is the offset is equal to:

      -ln(zi)

      crs 2/25/04 ;


   #delimit cr


   gen zi      = (WEIGHT/freq)
   gen neglnzi = -ln(zi)


  *Deal with zero cells
   replace neglnzi = 0 if neglnzi == .


*******************************
* CHECK SAMPLE SIZE AND CELLS *
*******************************

tab y
tab y [w=freq]



*********************
* VARIABLE CREATION *
*********************




gen ua = Wscale*Hscale



gen hypi = (Hscale > Wscale)
gen hypp = (Hp > Wp)

gen wz = (Wp == 0 & Hp > 0)
gen hz = (Hp == 0 & Wp > 0)
gen dc0 = (wz+hz)

      quietly gen hzC = 0
      quietly gen wzC = 0

      quietly foreach num of numlist 5(5)100 {
       quietly replace hzC = `num' if (hz == 1 & Wp == `num')
       quietly replace wzC = `num' if (wz == 1 & Hp  == `num')
      }




gen hs2 = (Hscale*Hscale)
gen ws2 = (Wscale*Wscale)
gen Hp2 = (Hp*Hp)
gen Wp2 = (Wp*Wp)

gen hi = (Wscale==Hscale)
gen h  = (Wp == Hp)

   ***Make the crossing variables (Johnson style)

        gen dc20 = (((Wp < 20 & Hp >= 20) | (Hp < 20 & Wp >= 20))  & Wp ~= 0 & Hp ~= 0)
        gen dc30 = (((Wp < 30 & Hp >= 30) | (Hp < 30 & Wp >= 30))  & Wp ~= 0 & Hp ~= 0)
        gen dc40 = (((Wp < 40 & Hp >= 40) | (Hp < 40 & Wp >= 40))  & Wp ~= 0 & Hp ~= 0)
        gen dc50 = (((Wp < 50 & Hp >= 50) | (Hp < 50 & Wp >= 50))  & Wp ~= 0 & Hp ~= 0)
        gen dc60 = (((Wp < 60 & Hp >= 60) | (Hp < 60 & Wp >= 60))  & Wp ~= 0 & Hp ~= 0)
        gen dc70 = (((Wp < 70 & Hp >= 70) | (Hp < 70 & Wp >= 70))  & Wp ~= 0 & Hp ~= 0)
        gen dc80 = (((Wp < 80 & Hp >= 80) | (Hp < 80 & Wp >= 80))  & Wp ~= 0 & Hp ~= 0)
        gen dc90 = (((Wp < 90 & Hp >= 90) | (Hp < 90 & Wp >= 90))  & Wp ~= 0 & Hp ~= 0)
        gen dc100 = (((Wp < 100 & Hp >= 100) | (Hp < 100 & Wp >= 100))  & Wp ~= 0 & Hp ~= 0)



***Distance in deciles, excluding zeros.


   gen d = 0
   replace d = 1 if abs(Wp - Hp) == 5 & Wp ~= 0 & Hp ~= 0
   replace d = 2 if abs(Wp - Hp) == 10 & Wp ~= 0 & Hp ~= 0
   replace d = 3 if abs(Wp - Hp) == 15 & Wp ~= 0 & Hp ~= 0
   replace d = 4 if abs(Wp - Hp) == 20 & Wp ~= 0 & Hp ~= 0
   replace d = 5 if abs(Wp - Hp) == 25 & Wp ~= 0 & Hp ~= 0
   replace d = 6 if abs(Wp - Hp) == 30 & Wp ~= 0 & Hp ~= 0
   replace d = 7 if abs(Wp - Hp) == 35 & Wp ~= 0 & Hp ~= 0
   replace d = 8 if abs(Wp - Hp) == 40 & Wp ~= 0 & Hp ~= 0
   replace d = 9 if abs(Wp - Hp) == 45 & Wp ~= 0 & Hp ~= 0
   replace d =10 if abs(Wp - Hp) == 50 & Wp ~= 0 & Hp ~= 0
   replace d =11 if abs(Wp - Hp) == 55 & Wp ~= 0 & Hp ~= 0
   replace d =12 if abs(Wp - Hp) == 60 & Wp ~= 0 & Hp ~= 0
   replace d =13 if abs(Wp - Hp) == 65 & Wp ~= 0 & Hp ~= 0
   replace d =14 if abs(Wp - Hp) == 70 & Wp ~= 0 & Hp ~= 0
   replace d =15 if abs(Wp - Hp) == 75 & Wp ~= 0 & Hp ~= 0
   replace d =16 if abs(Wp - Hp) == 80 & Wp ~= 0 & Hp ~= 0
   replace d =17 if abs(Wp - Hp) == 85 & Wp ~= 0 & Hp ~= 0
   replace d =18 if abs(Wp - Hp) == 90 & Wp ~= 0 & Hp ~= 0
   replace d =19 if abs(Wp - Hp) == 95 & Wp ~= 0 & Hp ~= 0


***Distance in scale scores, excluding zeros. Distance equals 0 when H = W.

   gen ds = 0

   forvalues i = 1/19 {
    replace ds = abs(Wscale-Hscale) if d == `i'
   }

   forvalues i = 1/19 {
     gen d`i' = (d == `i')
    }


   gen dsq  = d*d


***Distance between husbands and wives scale scores, excluding zeros. Distance is NOT equal to 0 when H = W.

    gen sd_hw = abs(Wscale-Hscale) if Wp ~= 0 & Hp ~= 0
    replace sd_hw = 0 if Wp == 0 | Hp == 0
    gen sd_hw2 = sd_hw*sd_hw
    gen sd_hw3 = sd_hw*sd_hw*sd_hw

    gen sd_hwexp = abs((oWscale/1000)-(oHscale/1000))
    gen sd_hwexp2 = sd_hwexp*sd_hwexp
    gen sd_hwd = sd_hw*d


  sort y Hp Wp
  tempfile full
  save `full'


    ***Distance, excluding zeros


      foreach num of numlist 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
       gen y`num' = (y == `num')
       quietly gen wzHpy`num' = (wz*Hp*y`num')
       quietly gen wzHp2y`num' = (wz*Hp*Hp*y`num')
       quietly gen hzWpy`num' = (hz*Wp*y`num')
      }

      foreach num of numlist 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
       quietly gen uazy`num' = (ua_std_ln*y`num')
       quietly gen uay`num'  = (ua_std_exp*y`num')
       quietly gen wzy`num'   = (wz*y`num')
       quietly gen hzy`num'   = (hz*y`num')
      }

      foreach num of numlist 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
        quietly gen dy`num' = (d*y`num')
        quietly gen sd_hwy`num' = (sd_hw*y`num')
      }


      gen wzHp  = wz*Hp
      gen wzHp2 = wz*Hp*Hp
      gen hzWp  = hz*Wp

      gen fwag = oWscale + oHscale



        list fwag oWscale oHscale WEIGHT if y == 1968
        list fwag oWscale oHscale WEIGHT if y == 2000



      forvalues i = 20(10)100 {
       gen Hp`i' = (Hp == `i')
       gen Hp`i'ws = (Hp`i'*Wscale)
      }


      foreach num of numlist 1972 1976 1980 1984 1988 1992 1996 2000 2004 {
       forvalues i = 20(10)100 {
        quietly gen wsHp`i'y`num' = (Wscale*Hp`i'*y`num')
       }
      }





   ***NOW MODEL.  SATURATE THE CROSS-SECTIONAL ASSOCATION


   set matsize 3000



***(3) Uniform association -- With special terms for zeros -- Model 3

    gen f03 = freq


    #delimit ;
    xi: glm f03 i.Wp*i.y i.Hp*i.y i.Wp*i.Hp
                uazy????
                wzHpy???? wzHp2y???? wzy???? , family(poisson) link(log) offset(neglnzi) ;
    #delimit cr


    matrix b=e(b)
    svmat b, n(eqcol)



*** Uniform association -- no hw -- Model 3


    gen f40 = freq

    #delimit ;
    xi: glm f40 i.Wp i.Hp ua_std_ln wzHp wzHp2 wz if y == 1968, family(poisson) link(log) offset(neglnzi) ;
    #delimit cr


    matrix b=e(b)
    svmat b, n(eqcol)


    ****CREATE ODDS***********


       gen e_uaz1968 = (f40ua_std_ln)

       foreach num of numlist 1972 1976 1980 1984 1988 1992 1996 2000 {
         quietly gen e_uaz`num' = (f40ua_std_ln + f03uazy`num')
       }



   drop f03* f40*




***(3) Uniform association -- with out zeros -- Model 2

    gen f03 = freq


    #delimit ;
    xi: glm f03 i.Wp*i.y i.Hp*i.y i.Wp*i.Hp uay???? , family(poisson) link(log) offset(neglnzi) ;
    #delimit cr


    matrix b=e(b)
    svmat b, n(eqcol)



*** Uniform association -- no hw --- Model 2


    gen f40 = freq

    #delimit ;
    xi: glm f40 i.Wp i.Hp ua_std_exp if y == 1968, family(poisson) link(log) offset(neglnzi) ;
    #delimit cr


    matrix b=e(b)
    svmat b, n(eqcol)


    ****CREATE ODDS***********


       gen e_ua1968 = (f40ua_std_exp)

       foreach num of numlist 1972 1976 1980 1984 1988 1992 1996 2000 {
         quietly gen e_ua`num' = (f40ua_std_exp + f03uay`num')
       }



   drop f03* f40*

*   preserve




  *** GRAPH  ***

    keep e_ua*
    keep in 1

    gen id = 1


    #delimit ;

    reshape long e_ua e_uaz, i(id) j(year) ;

    #delimit cr


     ***                                                 ***
     ***                                                 ***
     ***  AGRESTI 2002 page 270.                         ***
     ***                                                 ***
     ***  Re: uniform association and corr coefficients  ***
     ***                                                 ***
     ***  "For standardized scores, B is then comparable ***
     ***   to r/(1-r2), where r is the underlying        ***
     ***   correlation.  For weak assocations, B ~ r."   ***
     ***                                                 ***
     ***                                                 ***





    ***uniform association***


    *recode years to medians

    #delimit ;
    recode y  1968=1969.5 1972=1973.5 1976=1977.5 1980=1981.5
              1984=1985.5 1988=1989.5 1992=1993.5 1996=1997.5
              2000=2001.5 2004=2005;
    #delimit cr


   lab var e_uaz "Spouses with non-Zero Earnings (Model 3)"
   lab var e_ua  "All Couples (Model 2)"

          #delimit ;
      twoway connected  e_uaz e_ua year, c(l)
                                      mlcolor(gs0 gs0 gs0 gs0 gs0)
                                      mfcolor(gs12 gs0 gs0 gs0 gs0)
                                      clcolor(gs0 gs4 gs0 gs4 gs0)
                                      msize(medium medium medium medium medium)
                                      msymbol(/*s Oh*/ t o)
                                      yscale(r(-.1 .25)) ylabel(-.1(.05).25, labsize(*.9) labgap(.01))
                                      yline(0, lcolor(black))
                                      l1title("Linear-by-Linear Association", size(*.9))
                                      ytitle(" ")
                                      scheme(s1color)
                                      graphregion(fcolor(gs16)) plotregion(style(none))
                                      title(" ", size(medlarge) color(gs0)) sub(" ")
                  xlabel(1969.5 `" " 1967-" "1970" "' 1973.5 `" " 1971-" "1974" "'  1977.5 `" " 1975-" "1978" "'
                         1981.5 `" " 1979-" "1982" "' 1985.5 `" " 1983-" "1986" "'  1989.5 `" " 1987-" "1991" "'
                         1993.5 `" " 1991-" "1994" "' 1997.5 `" " 1995-" "1998" "'  2001.5 `" " 1999-" "2002" "'  2005 `" " 2003-" "2005" "', labsize(*.9))
                                            xtitle("Year", size(*.9)) legend(rows(2))
                                      xtitle("Year") legend(rows(2))
                                      ;
         #delimit cr

                 cd "U:\papers and projects\earnings associations\graphs"
    graph export ua_0105091.wmf, replace fontface(garamond)

exit
restore

