#delimit ;
*topcode_mcohab.do ;
capture log close ;
log using "u:\papers and projects\earnings associations\filecreation\topcode_mcohab.log", replace ;
set more 1 ;
clear ;
program drop _all ;
set mem 800M ;


*
* SAMPLE: Married & cohabiting couples age 22-55
*
*         No armed forces, farmers,
*         self-employed, group quarters,
*         or students.
*
;


#delimit cr


use "u:\papers and projects\earnings associations\dta\march_couples_121008.dta" , clear

gen m = 1

append using "u:\papers and projects\earnings associations\dta\posslq.dta"

replace m = 0 if m == .



*My analysis begins with the 1968 survey (1967 earnings info)


display _N

keep if y >= 68

display _N

tab y m


*         Drop armed forces, farmers,
*         self-employed, group quarters,
*         or students.


         *Keep those not in the armed forces
           tab waf_flag haf_flag, cell
           display _N
           keep if (waf_flag == 1 & haf_flag == 1 & m == 1) | m == 0
           display _N

         *Drop if either partner is self-employed
           tab wse_flag hse_flag, cell
           display _N
           drop if (wse_flag == 1 | hse_flag == 1) & m == 1
           display _N

         *Drop those working part year because of af, school, or retirement
           tab wpy_flag hpy_flag, cell
           display _N
           drop if (wpy_flag == 1 | hpy_flag == 1) & m == 1
           display _N


tab y m



       *
       * Determine the highest proportion of cases that are topcoded
       * out of all the years
       *

              gen ihmaxwag     = (hearn >= maxwag & hearn ~= .)
              gen ihmaxwag_all = (hearn_all >= maxwag & hearn_all ~= .)
              gen iwmaxwag     = (wearn >= maxwag & wearn ~= .)
              gen ihmaxinc     = (hinctot >= maxinc & hinctot ~= .)
              gen iwmaxinc     = (winctot >= maxinc & winctot ~= .)

              tab y ihmaxwag if hearn > 0, row
              tab y ihmaxwag_all if hearn_all > 0, row
              tab y iwmaxwag if wearn > 0, row
              tab y ihmaxinc, row
              tab y iwmaxinc, row



       *(6) Impose consistent top-code. My topcode is
       *    100-3.06 ~ 97.0.
       *
       *
       *



              *Following Cancian and Reed, if inctot = . set it to
              *zero

              *replace hinctot = 0 if hinctot == .
              *replace winctot = 0 if winctot == .


             *create new variables that contain top-coded earnings

              gen inctot = hinctot + winctot
              gen Wi     = winctot
              gen Hi     = hinctot
              gen W      = wearn
              gen H      = hearn
              gen W_all  = wearn_all
              gen H_all  = hearn_all
              gen FT     = ftotinc


              bysort y: egen pH = pctile(H),   p(97)
              bysort y: egen pW = pctile(W),   p(97)
              bysort y: egen pHi = pctile(Hi),   p(97)
              bysort y: egen pWi = pctile(Wi),   p(97)
              bysort y: egen pH_all = pctile(H_all),   p(97)
              bysort y: egen pW_all = pctile(W_all),   p(97)
              bysort y: egen pFT= pctile(FT),  p(97)

             *check
             tab pH if y == 100



             foreach i in W H FT Wi Hi {
              replace `i' = p`i' if `i' > p`i'
             }


             *The totals are the sums of the top-coded variables. I believe
             *that Cancian and Reed do it somewhat differently. They top-code
             *the total incomes as well as husbands' and wives' separately.

              gen Te     = H + W
              gen Te_all = H_all + W_all
              gen Ti     = Hi + Wi

             *check
             summarize H if y == 100, detail


       *    Karoly 1996 bottom codes at individuals with income below
       *    the bottom 2nd percentile.  This doesn't affect the results.
       *    Thus, follow Cancian and Reed and do not bottom code.

            *bysort y: egen pbhinctot = pctile(hinctot), p(2)
            *bysort y: egen pbwinctot = pctile(winctot), p(2)
            *bysort y: egen pbfaminc  = pctile(faminc), p(2)


            *foreach i in hinctot winctot faminc {
            * replace `i' = pb`i' if `i' <= pb`i'
            *}

          *   foreach i in hinctot winctot faminc {
          *    replace `i' = 0 if `i' <  0
          *   }



       *(7) Define residual income
       *
       *


       gen R = Ti-H-W



       *
       *
       * (8) convert to real dollars
       *
       *

         foreach var of varlist Ti Te Te_all W H R faminc FT ftotinc inctot  {
          replace `var' = `var'*cpr
         }



 keep Ti Te W_all H_all Te_all W H R faminc y WEIGHT cpr FT ftotinc inctot F wage Wi Hi m

 replace y = y + 1900


 lab var Ti      "Total income (H+W) (topcoded)"
 lab var Te      "Total earnings (H+W) (topcoded)"
 lab var Te_all  "Total earnings (H+W) (topcoded) (Inclds se + frm)"
 lab var W       "Wives' earnings"
 lab var H       "Husbands' earnings"
 lab var R       "Residual income"
 lab var faminc  "Family income"
 lab var WEIGHT  "H+W's person weight (varname=wgt)"
 lab var cpr     "CPI-U-RS"
 lab var FT      "Income of everyone in HH (topcoded)"
 lab var ftotinc "Income of everyone in HH (not topcoded)"
 lab var inctot  "Total income (H+W) (not topcoded)"
 lab var F       "Number of people in household"
 lab var wage    "Wife's age at interview"
 lab var Wi      "Wives' income (topcoded)"
 lab var Hi      "Husbands' income (topcoded)"
 lab var m       "Married=1, POSSLQ=0"

 describe

 quietly compress
 save "u:\papers and projects\earnings associations\dta\topcode_mcohab.dta", replace


 *What's the sample size?

  tab y

 log close

