#delimit ;
*topcode_selfemp.do ;
capture log close ;
log using "u:\papers and projects\earnings associations\filecreation\topcode_selfemp.log", replace ;
set more 1 ;
clear ;
program drop _all ;
set mem 500M ;


*
* This file imposes consistent topcodes on the preferred sample
* following Cancian and Reed (1999)
*
* SAMPLE: Married couples age 21-55 (as defined in march_couples_121008.do)
*
;


#delimit cr


use "u:\papers and projects\earnings associations\dta\march_couples_121008.dta" , clear



*         Drop armed forces, farmers,
*         self-employed, group quarters,
*         or students.

*         Test sensitivity to self-employed.




         *Keep those not in the armed forces
           tab waf_flag haf_flag, cell
           display _N
           keep if waf_flag == 1 & haf_flag == 1
           display _N

         *Drop if either partner is self-employed
           tab wse_flag hse_flag, cell
           display _N
        *  drop if wse_flag == 1 | hse_flag == 1
           display _N

         *Drop those working part year because of af, school, or retirement
           tab wpy_flag hpy_flag, cell
           display _N
           drop if wpy_flag == 1 | hpy_flag == 1
           display _N




       *
       * Determine the highest proportion of cases that are topcoded
       * out of all the years
       *

              gen ihmaxwag     = (hearn >= maxwag & hearn ~= .)
              gen ihmaxwag_all = (hearn_all >= maxwag & hearn_all ~= .)
              gen iwmaxwag     = (wearn >= maxwag & wearn ~= .)
              gen ihmaxinc     = (hinctot >= maxinc & hinctot ~= .)
              gen iwmaxinc     = (winctot >= maxinc & winctot ~= .)

              tab y ihmaxwag if hearn > 0, row
              tab y ihmaxwag_all if hearn_all > 0, row
              tab y iwmaxwag if wearn > 0, row
              tab y ihmaxinc, row
              tab y iwmaxinc, row


       * The maximum percentage of cases that hit the topcode
       * is 2.99% of husbands' wages from all sources in 1981.


       *(6) Impose Cancian and Reed's consistent top-code: 4.7%.
       *    They do this separately by marital status and sex.
       *    Test my topcode of 100-2.99 = 97.0.
       *
       *    MAKE SURE THIS HASN'T CHANGED IF I'VE CHANGED THE SAMPLE!!!!
       *
       *



              *Following Cancian and Reed, if inctot = . set it to
              *zero

              *replace hinctot = 0 if hinctot == .
              *replace winctot = 0 if winctot == .


             *create new variables that contain top-coded earnings

              gen inctot = hinctot + winctot
              gen Ti     = hinctot + winctot
              gen W      = wearn
              gen H      = hearn
              gen W_all  = wearn_all
              gen H_all  = hearn_all
              gen FT     = ftotinc


              bysort y: egen pH = pctile(H),   p(97)
              bysort y: egen pW = pctile(W),   p(97)
              bysort y: egen pH_all = pctile(H_all),   p(97)
              bysort y: egen pW_all = pctile(W_all),   p(97)
              bysort y: egen pTi = pctile(Ti), p(97)
              bysort y: egen pFT= pctile(FT),  p(97)

             *check
             tab pH if y == 100



             foreach i in W H FT {
              replace `i' = p`i' if `i' > p`i'
             }


             *The totals are the sums of the top-coded variables. I believe
             *that Cancian and Reed do it somewhat differently. They top-code
             *the total incomes as well as husbands' and wives' separately.

              gen Te     = H + W
              gen Te_selfemp = H_all + W_all


             *check
             summarize H if y == 100, detail


       *    Karoly 1996 bottom codes at individuals with income below
       *    the bottom 2nd percentile.  This doesn't affect the results.
       *    Thus, follow Cancian and Reed and do not bottom code.

            *bysort y: egen pbhinctot = pctile(hinctot), p(2)
            *bysort y: egen pbwinctot = pctile(winctot), p(2)
            *bysort y: egen pbfaminc  = pctile(faminc), p(2)


            *foreach i in hinctot winctot faminc {
            * replace `i' = pb`i' if `i' <= pb`i'
            *}

          *   foreach i in hinctot winctot faminc {
          *    replace `i' = 0 if `i' <  0
          *   }



       *(7) Define residual income
       *
       *


       gen R = Ti-H-W



       *
       *
       * (8) convert to real dollars
       *
       *

         foreach var of varlist Ti Te Te_selfemp W H R faminc FT ftotinc inctot  {
          replace `var' = `var'*cpr
         }



 keep Ti Te W_all H_all Te_selfemp W H R faminc y WEIGHT cpr FT ftotinc inctot F wage

 replace y = y + 1900


 lab var Ti      "Total income (H+W) (topcoded)"
 lab var Te      "Total earnings (H+W) (topcoded)"
 lab var Te_selfemp  "Total earnings (H+W) (topcoded) (Inclds se + frm)"
 lab var W       "Wives' earnings"
 lab var H       "Husbands' earnings"
 lab var R       "Residual income"
 lab var faminc  "Family income"
 lab var WEIGHT  "H+W's person weight (varname=wgt)"
 lab var cpr     "CPI-U-RS"
 lab var FT      "Income of everyone in HH (topcoded)"
 lab var ftotinc "Income of everyone in HH (not topcoded)"
 lab var inctot  "Total income (H+W) (not topcoded)"
 lab var F       "Number of people in household"
 lab var wage    "Wife's age at interview"

 describe

 quietly compress
saveold "u:\papers and projects\earnings associations\dta\topcode_selfemp.dta", replace


 *What's the sample size?

  tab y

 log close

